﻿<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/default_dune_plugin_fw.php';
require_once 'lib/default_dune_plugin.php';
require_once 'lib/utils.php';
require_once 'lib/control_factory.php';
require_once 'lib/action_factory.php';
require_once 'lib/list_util.php';

require_once 'utils.php';

require 'cursor.php';
require 'folder.php';
require 'folder_cache.php';
require 'playback_url_cache.php';
require 'video_cache.php';


///////////////////////////////////////////////////////////////////////////

$hd_interface_language = 'english';

///////////////////////////////////////////////////////////////////////////

function update_interface_language()
{
    global $hd_interface_language;

    $v =
        trim(
            shell_exec(
                "grep 'interface_language' /config/settings.properties" . ' | sed "s/^.*= *//"'));

    $lang_saved = $hd_interface_language;
    $hd_interface_language = (isset($v) && strlen($v) > 0) ? $v : 'english';

    return ($lang_saved !== $hd_interface_language) ? 1 : 0;
}

///////////////////////////////////////////////////////////////////////////

function get_interface_language()
{
    global $hd_interface_language;
    return $hd_interface_language;
}

function is_interface_language_russian_or_similar()
{
    return get_interface_language() === 'russian' ||
        get_interface_language() === 'ukrainian';
}

///////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////

class FussballPlugin extends DefaultDunePlugin implements UserInputHandler
{
    const ID = 'Fussball';
    ///////////////////////////////////////////////////////////////////////
    
    private $fav_build_in_progess;

    private static $open_folder_action = array
    (
        GuiAction::handler_string_id => PLUGIN_OPEN_FOLDER_ACTION_ID,
    );

    ///////////////////////////////////////////////////////////////////////

    private static $vod_play_action = array
    (
        GuiAction::handler_string_id => PLUGIN_VOD_PLAY_ACTION_ID,
        GuiAction::caption           => 'Play'
    );

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    private static $catalog_vip = array
    (
        ViewItemParams::icon_path => 'gui_skin://small_icons/folder.aai',
        ViewItemParams::item_layout => HALIGN_LEFT,
        ViewItemParams::icon_valign => VALIGN_CENTER,
        ViewItemParams::icon_dx => 20,
        ViewItemParams::icon_dy => -5,
        ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
        ViewItemParams::item_caption_width => 1550
    );

    public static function get_skin_path($plugin_cookies)
    {
        $skin = isset($plugin_cookies->skin) ? $plugin_cookies->skin : 'default';
        
        $skins = array
        (
            'default' =>  'plugin_file://skins/default/',
            'juniperus' => 'plugin_file://skins/juniperus/'
        );
        
        return $skins[$skin];
    }

    public static function get_main_vip($plugin_cookies)
    {
        $skin = isset($plugin_cookies->skin) ? $plugin_cookies->skin : 'default';
        
        $skins = array
        (
            'default' =>  array
                            (
                                ViewItemParams::icon_scale_factor =>0.75,
                                ViewItemParams::icon_sel_scale_factor =>1,
                                ViewItemParams::icon_path => 'gui_skin://small_icons/folder.aai',
                                ViewItemParams::item_layout => VALIGN_CENTER,
                                ViewItemParams::icon_valign => VALIGN_CENTER,
                                ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL
                            ),
            'juniperus' =>    array
                            (
                                ViewItemParams::icon_scale_factor =>1.0,        //jun
                                ViewItemParams::icon_sel_scale_factor =>1.2,        //jun
                                ViewItemParams::icon_path => 'gui_skin://small_icons/folder.aai',
                                ViewItemParams::item_layout => VALIGN_CENTER,
                                ViewItemParams::icon_valign => VALIGN_CENTER,
                                ViewItemParams::item_caption_dy => -50,                     //jun
                                ViewItemParams::item_caption_sel_dy => -15,                //jun
                                ViewItemParams::icon_dy => -14,                            //jun
                                ViewItemParams::icon_sel_dy => -14,                         //jun
                                ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL
                            )
        );
        
        return $skins[$skin];
    }

    public static function get_main_menu_folder_view($plugin_cookies)
    {
        $skin = isset($plugin_cookies->skin) ? $plugin_cookies->skin : 'default';
        
        $skins = array
        (
            'juniperus' =>  array
                            (
                                ViewParams::num_cols => 4,        //jun
                                ViewParams::num_rows => 2,        //jun
                                ViewParams::icon_selection_box_dx => -118,        //jun
                                ViewParams::icon_selection_box_dy => -154,        //jun
                                ViewParams::icon_selection_box_width => 240,        //jun
                                ViewParams::icon_selection_box_height => 240,        //jun
                                ViewParams::paint_sandwich => false,                    //jun
                                ViewParams::sandwich_base => 'gui_skin://special_icons/sandwich_base.aai',
                                ViewParams::sandwich_mask => 'cut_icon://{name=sandwich_mask}',
                                ViewParams::sandwich_cover => 'cut_icon://{name=sandwich_cover}',
                                ViewParams::sandwich_width => 200,            //jun
                                ViewParams::sandwich_height => 200,         //jun
                                ViewParams::sandwich_icon_upscale_enabled => false,        //jun
                                ViewParams::paint_details => false        //jun
                            ),
            'default' =>    array
                            (
                                ViewParams::num_cols => 3,
                                ViewParams::num_rows => 2,
                                ViewParams::icon_selection_box_dx => -100,
                                ViewParams::icon_selection_box_dy => -100,
                                ViewParams::icon_selection_box_width => 324,
                                ViewParams::icon_selection_box_height => 200,
                                ViewParams::paint_sandwich => true,
                                ViewParams::sandwich_base => 'gui_skin://special_icons/sandwich_base.aai',
                                ViewParams::sandwich_mask => 'cut_icon://{name=sandwich_mask}',
                                ViewParams::sandwich_cover => 'cut_icon://{name=sandwich_cover}',
                                ViewParams::sandwich_width => 324,
                                ViewParams::sandwich_height => 180,
                                ViewParams::sandwich_icon_upscale_enabled => false,
                                ViewParams::paint_details => true
                            ),
        );
        
        return $skins[$skin];
    }

    public function __construct()
    {
        $this->fav_build_in_progess = false;
    }

    private static function get_preview_url($v)
    {
        if (!HD::has_attribute($v, 'season_image'))
            return '';

        return $v->season_image;
    }

    private function get_quality_array($cfg)
    {
        // 240, 360, 480, 720 и 1080
        $vquality = array();
        if ($cfg === true)
            $vquality[0] = '2013';
        else
            $vquality[0] = '2013';
        $vquality[1] = 'Все года';
        $vquality[2] = '2012';
        $vquality[3] = '2011';
        if ($cfg === true)
            $vquality[4] = '2010';
        else
            $vquality[4] = '2010';

        return $vquality;        
    }
	private function get_poisk_array($cfg)
    {
        // production
        $vpoisk = array();
        if ($cfg === true)
        $vpoisk[0] = 'Видео';
        else
        $vpoisk[0] = 'Видео';
        $vpoisk[1] = 'Не выбрано';
        if ($cfg === true)
            $vpoisk[2] = 'Аудио';
        else
            $vpoisk[2] = 'Аудио';

        return $vpoisk;        
    }
	private function get_sorting_array($cfg)
    {
        // sort
        $vsorting = array();
        if ($cfg === true)
        $vsorting[0] = 'по рейтингу';
        else
        $vsorting[0] = 'по рейтингу';
        $vsorting[1] = 'по дате обновления';
        if ($cfg === true)
            $vsorting[2] = 'по просмотрам';
        else
            $vsorting[2] = 'по просмотрам';

        return $vsorting;        
    }
	private function get_production_array($cfg)
    {
        // production
        $vproduction = array();
        if ($cfg === true)
        $vproduction[0] = 'Показывать Аниме и Эротика';
        else
        $vproduction[0] = 'Показывать Аниме и Эротика';
        $vproduction[1] = 'Не выбрано';
        if ($cfg === true)
            $vproduction[2] = 'Не показывать Аниме и Эротика';
        else
            $vproduction[2] = 'Не показывать Аниме и Эротика';

        return $vproduction;        
    }
	private function get_language_array($cfg)
    {
        // language
        $vlanguage = array();
        if ($cfg === true)
        $vlanguage[0] = 'Зарубежное';
        else
        $vlanguage[0] = 'Зарубежное';
        $vlanguage[1] = 'Не выбрано';
        if ($cfg === true)
            $vlanguage[2] = 'Наше';
        else
            $vlanguage[2] = 'Наше';

        return $vlanguage;        
    }
	//resolution
	 private function get_resolution_array($cfg)
    {
        // 240, 360, 480, 720 и 1080
        $vresolution = array();
        if ($cfg === true)
            $vresolution[0] = 'Только HD';
        else
            $vresolution[0] = 'Только HD';
        $vresolution[1] = 'Не выбрано - любое';
        $vresolution[2] = 'Только HD и HQ';
        if ($cfg === true)
            $vresolution[3] = 'Только HD и HQ и SQ';
        else
            $vresolution[3] = 'Только HD и HQ и SQ';

        return $vresolution;        
    }
	
    ///////////////////////////////////////////////////////////////////////
    public function get_play_action($media_url, &$plugin_cookies)
    {
        $add_play_action = UserInputHandlerRegistry::create_action(
                        $this, 'play_item');
        $add_play_action['caption'] = (
                is_interface_language_russian_or_similar() ? 'Воспроизвести' : "Play"
                );

        return $add_play_action;

    }

    ///////////////////////////////////////////////////////////////////////
    public function get_item_action_map($media_url, &$plugin_cookies)
    {
        $add_fav_action = UserInputHandlerRegistry::create_action(
                        $this, 'add_favorite');
        $add_fav_action['caption'] = (
                is_interface_language_russian_or_similar() ? 'Добавить в Избранное' : "Add Favorite"
                );

        $switch_view = UserInputHandlerRegistry::create_action(
                        $this, 'switch_view');
        $switch_view['caption'] = (
                is_interface_language_russian_or_similar() ? "Вид" : 'View mode'
                );
        $view_info = UserInputHandlerRegistry::create_action(
                        $this, 'ex_view_info');
        $view_info['caption'] = (
                is_interface_language_russian_or_similar() ? "Инфо" : 'Info'
                );

        $skip_details = isset($plugin_cookies->skip_details) ? $plugin_cookies->skip_details : 'no';

        if ($skip_details === 'yes')
        {
            return array
                (
                GUI_EVENT_KEY_ENTER => UserInputHandlerRegistry::create_action($this, 'view_series'),
                GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                GUI_EVENT_KEY_A_RED => $switch_view,
                GUI_EVENT_KEY_INFO => $view_info,
                GUI_EVENT_KEY_C_YELLOW => $add_fav_action
            );
            
        }
        else
        {
            return array
                (
                GUI_EVENT_KEY_ENTER => $view_info,
                GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                GUI_EVENT_KEY_A_RED => $switch_view,
                GUI_EVENT_KEY_C_YELLOW => $add_fav_action
            );
            
        }
    }

    ///////////////////////////////////////////////////////////////////////
    public function get_search_action_map($media_url, &$plugin_cookies)
    {
        $perform_search_action = UserInputHandlerRegistry::create_action(
                        $this, 'perform_search');
        $perform_search_action['caption'] = (
                is_interface_language_russian_or_similar() ? 'Выполнить поиск' : "Perform Search"
                );
        $add_search_action = UserInputHandlerRegistry::create_action(
                        $this, 'add_search');
        $add_search_action['caption'] = (
                is_interface_language_russian_or_similar() ? 'Добавить поиск' : "Add Search"
                );
        $remove_search_action = UserInputHandlerRegistry::create_action(
                        $this, 'remove_search');
        $remove_search_action['caption'] = (
                is_interface_language_russian_or_similar() ? "Удалить" : 'Remove'
                );
        $move_search_top_action = UserInputHandlerRegistry::create_action(
                        $this, 'move_search_top');
        $move_search_top_action['caption'] = (
                is_interface_language_russian_or_similar() ? "Переместить вверх" : 'Move to top'
                );
        $menu_items[] = array(
            GuiMenuItemDef::caption => $move_search_top_action['caption'],
           GuiMenuItemDef::action => $move_search_top_action
        );
        $menu_items[] = array(
            GuiMenuItemDef::caption => $remove_search_action['caption'],
            GuiMenuItemDef::action => $remove_search_action
        );
        $popup_search_action = ActionFactory::show_popup_menu($menu_items);
        $do_search_action = UserInputHandlerRegistry::create_action($this, 'do_search');
        return array
            (
            GUI_EVENT_KEY_ENTER => $do_search_action,
            GUI_EVENT_KEY_POPUP_MENU => $popup_search_action
        );
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_fav_action_map($media_url, &$plugin_cookies)
    {
        $remove_fav_action = UserInputHandlerRegistry::create_action(
                        $this, 'remove_fav');
        $remove_fav_action['caption'] = (
                is_interface_language_russian_or_similar() ? "Удалить" : 'Remove'
                );
        $move_fav_top_action = UserInputHandlerRegistry::create_action(
                        $this, 'move_fav_top');
        $move_fav_top_action['caption'] = (
                is_interface_language_russian_or_similar() ? "Переместить вверх" : 'Move to top'
                );
        $switch_view = UserInputHandlerRegistry::create_action(
                        $this, 'switch_view');
        $switch_view['caption'] = (
                is_interface_language_russian_or_similar() ? "Вид" : 'View mode'
                );
        $view_info = UserInputHandlerRegistry::create_action(
                        $this, 'ex_view_info');
        $view_info['caption'] = (
                is_interface_language_russian_or_similar() ? "Инфо" : 'Info'
                );
       $menu_items[] = array(
            GuiMenuItemDef::caption => $move_fav_top_action['caption'],
            GuiMenuItemDef::action => $move_fav_top_action
        );
        $menu_items[] = array(
            GuiMenuItemDef::caption => $remove_fav_action['caption'],
            GuiMenuItemDef::action => $remove_fav_action
        );
        $popup_search_action = ActionFactory::show_popup_menu($menu_items);

        $skip_details = isset($plugin_cookies->skip_details) ? $plugin_cookies->skip_details : 'no';

        if ($skip_details === 'yes')
        {
            return array
                (
                GUI_EVENT_KEY_ENTER => UserInputHandlerRegistry::create_action($this, 'view_series'),
                GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                GUI_EVENT_KEY_A_RED => $switch_view,
                GUI_EVENT_KEY_INFO => $view_info,
                GUI_EVENT_KEY_POPUP_MENU => $popup_search_action
            );
        }
        else
        {
            return array
                (
                GUI_EVENT_KEY_ENTER => $view_info,
                GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                GUI_EVENT_KEY_A_RED => $switch_view,
                GUI_EVENT_KEY_POPUP_MENU => $popup_search_action
            );
        }
    }

    ///////////////////////////////////////////////////////////////////////
    public function get_video_action_map($media_url, &$plugin_cookies) 
    {
        return array
            (
            GUI_EVENT_KEY_ENTER => self::$open_folder_action        );
    }

    ///////////////////////////////////////////////////////////////////////
    public function get_main_menu_action_map($media_url, &$plugin_cookies)
    {

        return array
            (
            GUI_EVENT_KEY_ENTER => self::$open_folder_action
        );
    }

    ///////////////////////////////////////////////////////////////////////
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        //hd_print('--> Entry handler: handle_user_input:');
        foreach ($user_input as $key => $value)
            //hd_print("  $key => $value");
        update_interface_language();

        $do_search_action = UserInputHandlerRegistry::create_action($this, 'do_search');
        $do_new_search_action = UserInputHandlerRegistry::create_action($this, 'do_new_search');
        $perform_new_search_action = UserInputHandlerRegistry::create_action($this, 'perform_new_search');
        $do_add_search_action = UserInputHandlerRegistry::create_action($this, 'do_add_search');
        $do_mark_viewed = UserInputHandlerRegistry::create_action($this, 'mark_viewed');
        $add_fav_complite = UserInputHandlerRegistry::create_action($this, 'add_fav_complite');
        $del_fav_complite = UserInputHandlerRegistry::create_action($this, 'del_fav_complite');
        $just_play = UserInputHandlerRegistry::create_action($this, 'just_play');

        if (isset($user_input->control_id))
        {
            $control_id = $user_input->control_id;
            switch ($control_id)
            {
                case 'search':
                    $new_value = $user_input->{$control_id};
                    // last entered search
                    $plugin_cookies->search = $new_value;
                    $defs = $this->do_get_search_defs($plugin_cookies);
                    return  ActionFactory::reset_controls
                            (
                                $defs,
                                null,
                                1
                            );
//                    return null;
                case 'perform_new_search':
                    $new_value = $plugin_cookies->search;
                    // perform search
                    $search_text = urlencode($new_value);
                    //hd_print("Search: performing search of $search_text");
                    $search_url = HD::encode_user_data(array('ser_feed' => $search_text));
                    return array
                    (
                        GuiAction::handler_string_id => PLUGIN_OPEN_FOLDER_ACTION_ID,
                        GuiAction::data =>
                        array
                        (
                            'media_url' => $search_url
                        )
                    );
                case 'do_new_search':
                    $new_value = $plugin_cookies->search;
                    // search history
                    $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
                    $plugin_cookies->search_items = ListUtil::add_item($search_items,$new_value);
                    return ActionFactory::invalidate_folders(array($user_input->parent_media_url), $perform_new_search_action);
                case 'do_search':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
                    if ($user_data->ser_feed != '')
                        break;

                    $defs = $this->do_get_search_defs($plugin_cookies);

                    return ActionFactory::show_dialog(
                            (is_interface_language_russian_or_similar() ? 'Поиск' : 'Search'),
                            $defs);
                    
                    break;
                case 'skin':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->skin = $new_value;
                    shell_exec("cp -f /persistfs/plugins/Tree.tv/skins/$new_value/icons/logo.png /persistfs/plugins/Tree.tv/skins/logo.png");
                    break;
                case 'restart':
					shell_exec('killall shell');
                    break;
				case 'info_release':
                   
					$post_action = null;
					
						$text = HD::http_get_document('http://dl.dropboxusercontent.com/u/13455121/Dune/update/Tree.tv/info.txt');
						$defs = array();
						$texts = explode("\n", $text);
						$texts = array_values($texts);
						foreach($texts as $text)
						{
						$text = str_remove_spec($text);
						ControlFactory::add_label($defs, "", $text);
						}
						ControlFactory::add_custom_close_dialog_and_apply_buffon($defs, 'setup', 'Ok', 150,  $post_action);

						return ActionFactory::show_dialog('Информация об изменениях.', $defs);

					
                    break;
              


  case 'show_main_icon':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->main_icon = $new_value;
		            if ($new_value == 'yes')
		            {
			            $plugin_cookies->show_channels_v4 = 'no';
			            $plugin_cookies->show_search_v4 = 'no';
			            $plugin_cookies->show_favorites = 'no';
		            }
		            else
		            {
			            $plugin_cookies->show_channels_v4 = 'yes';
			            $plugin_cookies->show_search_v4 = 'yes';
			            $plugin_cookies->show_favorites = 'yes';
		            }
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
                    break;
                case 'video_quality':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->video_quality = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
					break;
				

case 'video_poisk':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->video_poisk = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
					break;	
				case 'video_sorting':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->video_sorting = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
					break;
				case 'video_production':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->video_production = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
					break;
				case 'video_language':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->video_language = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
					break;
				case 'video_resolution':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->video_resolution = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );	
                    break;





/////////////////////////////////////////////////////////////////////////////////////////////////////////////////				


case 'user_folder':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->user_folder = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
                    break;
  

case 'user_login':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->user_login = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
                    break;
 



case 'user_password':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->user_password = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
                    break;
 


//////////////////////////////////////////////////////////////////////////////////////////////////////////////


              case 'use_osk':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->use_osk = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
                    break;
                case 'skip_details':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->skip_details = $new_value;
                    return ActionFactory::reset_controls(
                            $this->do_get_control_defs($plugin_cookies)
                    );
                    break;

                case 'buf_time':
                    $new_value = $user_input->{$control_id};
                    //hd_print("Setup: changing $control_id value to $new_value");
                    $plugin_cookies->buf_time = $new_value;
                    return  ActionFactory::reset_controls
                            (
                                $this->do_get_control_defs($plugin_cookies)
                            );
                    break;
                case 'ex_view_info':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
                    
                    if (!HD::has_attribute($user_data, 'video_id'))
                        return null;
                        
                    return array
                        (
                             GuiAction::handler_string_id => PLUGIN_OPEN_FOLDER_ACTION_ID,
                             GuiAction::data => array(
                                    'media_url' => HD::encode_user_data(
                                                        array(
                                                            'info' => '1',
                                                            'video_id' => $user_data->video_id,
                                                            'season_ref' => $user_data->video_id,
                                                            //'season_title' => $user_data->season_title,
                                                        )
                                                    )
                             )
                         );
                    break;
                    
                case 'add_fav_complite':
                    return ActionFactory::show_title_dialog(
                        (
                            is_interface_language_russian_or_similar() ? 'Видео добавлено в избранное' : "Video has been added to favorites"
                        )
                    );
                    break;
                 case 'del_fav_complite':
                    return ActionFactory::show_title_dialog(
                        (
                            is_interface_language_russian_or_similar() ? 'Видео было удалено из избранного' : "Video has been deleted from favorites"
                        )
                    );
                    break;
					
               







 case 'wget_download':
                    if (!isset($user_input->selected_media_url))
                        return null;
					$folder_s = isset($plugin_cookies->user_folder) ? $plugin_cookies->user_folder : 1;
					$folder_s = '/D/'.$folder_s.'/';
					$folder_s = str_replace('/D//', '/D/', $folder_s);
                    $user_data = $user_input->selected_media_url;
					$tmp = explode('episode_ref":"', $user_data);
					$aria_link = str_remove_spec(strstr($tmp[1], '"', true));
					$tmp = explode('episode_title":"', $user_data);
					$aria_name = str_remove_spec(strstr($tmp[1], '"', true));
					shell_exec("wget -c -t 0 $aria_link -P $folder_s > /tmp/run/aria_fs.log &");
					return ActionFactory::show_title_dialog("$aria_name - добавлен в закачки");




					
                case 'aria_inf':
				
					$lines = file('/tmp/run/aria_fs.log'); 
					$trans_log = $lines[count($lines)-1]; 
					$trans_log = str_remove_spec($trans_log);
					$trans_log = str_replace('#1 SIZE:', 'Загружено/Размер:', $trans_log);
					$trans_log = str_replace(' CN:2', '', $trans_log);
					$trans_log = str_replace('SPD', 'Скорость загрузки', $trans_log);
					$trans_log = str_replace('ETA', 'Осталось', $trans_log);
					$trans_log = str_replace('(OK):download completed.', 'Закачки завершены.', $trans_log);
					return ActionFactory::show_title_dialog($trans_log);
                    break;
				
				




case 'aria_download':
					if (!isset($user_input->selected_media_url))
                        return null;
					$folder_s = isset($plugin_cookies->user_folder) ? $plugin_cookies->user_folder : 1;
					$folder_s = '/D/'. $folder_s;
					$folder_s = str_replace('1', '', $folder_s);
                    $user_data = $user_input->selected_media_url;
					$tmp = explode('episode_ref":"', $user_data);
					$aria_link = str_remove_spec(strstr($tmp[1], '"', true));
					$tmp = explode('episode_title":"', $user_data);
					$aria_name = str_remove_spec(strstr($tmp[1], '"', true));
					exec("/ltu/bin/aria2c -x2 $aria_link --dir=$folder_s > /tmp/run/aria_fs.log &");
					return ActionFactory::show_title_dialog("$aria_name - добавлен в закачки");
                    break;












	
                case 'add_favorite':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    if ($user_input->selected_media_url === 'right_button')
                        HD::decode_user_data($user_input->parent_media_url, $media_str, $user_data);
                    else
                        HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
		            
                    if (HD::has_attribute($user_data, 'video_id'))
                    	$video_id = $user_data->video_id;
                    else
                        return null;

                    $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';

                    if (!ListUtil::is_in_list($fav_items, $video_id))
                    {
		                $plugin_cookies->fav_items = ListUtil::add_item($fav_items,$video_id);
                        $plugin_cookies->$video_id = "";
          
                        $items = $this->parse_season($video_id, $plugin_cookies);

                        foreach($items as $v)
                        {
                            HD::decode_user_data($v, $media_str, $udata);
                            
                            $s = $udata->episode_ref;

                            if (strlen($s) == 0)
                                continue;
                                
                            $i = $plugin_cookies->$video_id;
                            
                            $plugin_cookies->$video_id = ListUtil::add_item($i, $s);
                        }
                        
                        if ($user_input->selected_media_url === 'right_button')
                        {
                            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), $add_fav_complite);
                        }
                        else
                        {
                            return ActionFactory::show_title_dialog('Видео добавлено в избранное');
                        }
                    }
                    else
                    {
                        return ActionFactory::show_title_dialog('Видео уже в избранном');
                    }
                    break;
                case 'remove_fav':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    if ($this->fav_build_in_progess)
                        return ActionFactory::show_title_dialog('Подождите окончания построения списка!');
                        
                    if ($user_input->selected_media_url === 'right_button')
                        HD::decode_user_data($user_input->parent_media_url, $media_str, $user_data);
                    else
                        HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);

                    if (HD::has_attribute($user_data, 'video_id'))
                        $video_id = $user_data->video_id;
                    else if (HD::has_attribute($user_data, 'fav'))
                        $video_id = $user_data->fav;
                    else
                        return null;

                    $fav_items = isset($plugin_cookies->fav_items) ? ListUtil::del_item($plugin_cookies->fav_items, $video_id) : '';
                    $plugin_cookies->fav_items = $fav_items;
                    if (isset($plugin_cookies->$video_id))
                    {
                        unset($plugin_cookies->$video_id);
                    }
                    //{ Viewed items
                    $s = $video_id . ".viewed";
                    if (isset($plugin_cookies->$s))
                    {
                        unset($plugin_cookies->$s);
                    }
                    //} Viewed items

                    $folder = FolderCache::get('main_menu:fav');
                    $folder->set_expired();
                    if ($user_input->selected_media_url === 'right_button')
                    {
                        return ActionFactory::invalidate_folders(array($user_input->parent_media_url), $del_fav_complite);
                    }
                    else
                    {
                        return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
                    }
                    break;
                case 'move_fav_top':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    if ($this->fav_build_in_progess)
                        return ActionFactory::show_title_dialog('Подождите окончания построения списка!');
                    HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
                    $video_id = $user_data->video_id;
                    $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
                    $plugin_cookies->fav_items = ListUtil::add_item($fav_items,$video_id);
                    return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
                    break;

                case 'just_play':
                    return array(
                            GuiAction::handler_string_id => PLUGIN_VOD_PLAY_ACTION_ID,
                            GuiAction::data =>
                                array(
                                    'media_url' => $user_input->selected_media_url
                                )
                    );
                    break;
                case 'play_item':
                    if (!isset($user_input->selected_media_url))
                        return null;
         
                    return ActionFactory::invalidate_folders(array($user_input->selected_media_url, $user_input->parent_media_url), $just_play);

                    break;
		        case 'view_series':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    
                    HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);

		            $n_series = 0;
		            if (HD::has_attribute($user_data, 'n_series'))
			            $n_series = $user_data->n_series;
	
		            $ndx_series = -1;
		            if (HD::has_attribute($user_data, 'ndx_series'))
			            $ndx_series = $user_data->ndx_series;

		            if ($n_series < 2 || $ndx_series >= 0)
		            {
	                    return array(
        	                GuiAction::handler_string_id => PLUGIN_VOD_PLAY_ACTION_ID,
                	        GuiAction::data =>
                        	array(
	                            'media_url' => $user_input->selected_media_url
        	                )
			            );
		            }
		            else
		            {
	                    return array(
        	                GuiAction::handler_string_id => PLUGIN_OPEN_FOLDER_ACTION_ID,
                	        GuiAction::data =>
                        	array(
	                            'media_url' => $user_input->selected_media_url
        	                )
			            );
                   }
		           break;
                case 'remove_search':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
                    $ser_feed = urldecode($user_data->ser_feed);
                    //hd_print("removing search: $ser_feed");
                    $search_items = isset($plugin_cookies->search_items) ? ListUtil::del_item($plugin_cookies->search_items, $ser_feed) : '';
                    $plugin_cookies->search_items = $search_items;
                    //hd_print("-- search list: $search_items");
                    return ActionFactory::update_regular_folder(
                                    $this->get_regular_folder_items('main_menu:search', 0, $plugin_cookies), true);
                    break;
                case 'move_search_top':
                    if (!isset($user_input->selected_media_url))
                        return null;
                    HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
                    $ser_feed = urldecode($user_data->ser_feed);
                    $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
                    $plugin_cookies->search_items = ListUtil::add_item($search_items,$ser_feed);
                    return ActionFactory::update_regular_folder(
                                    $this->get_regular_folder_items('main_menu:search', 0, $plugin_cookies), true);
                    break;
                case 'mark_viewed':
                    //'url_series'
                    if (isset($user_input->selected_media_url))
                    {
                        HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
                        if (HD::has_attribute($user_data, 'video_id'))
                            $video_id = $user_data->video_id;
                        else if (HD::has_attribute($user_data, 'season_ref'))
                            $video_id = $user_data->season_ref;
                        
                            if (isset($plugin_cookies->$video_id))
                            {
                                if (HD::has_attribute($user_data, 'url_series'))
                                    $url = $user_data->url_series;
                                else if (HD::has_attribute($user_data, 'episode_ref'))
                                    $url = $user_data->episode_ref;
                                if (!ListUtil::is_in_list($plugin_cookies->$video_id, $url))
                                {
                                    $viewed = $plugin_cookies->$video_id;
                                    $plugin_cookies->$video_id = ListUtil::add_item($viewed,$url);
                                }
                            }
							//{ Viewed items
                            
                            $s = $video_id . ".viewed";
                            if (!isset($plugin_cookies->$s))
                                $plugin_cookies->$s = "";
                            if (HD::has_attribute($user_data, 'url_series'))
                                $url = $user_data->url_series;
                            else if (HD::has_attribute($user_data, 'episode_ref'))
                                $url = $user_data->episode_ref;
                            if (!ListUtil::is_in_list($plugin_cookies->$s, $url))
                            {
                                $i = $plugin_cookies->$s;       
                                $plugin_cookies->$s = ListUtil::add_item($i, $url);
                            }
							else
							{
								$i = $plugin_cookies->$s; 
								$plugin_cookies->$s = ListUtil::del_item($i, $url);
							}
                            //} Viewed items

                        
                    }
                    return ActionFactory::update_regular_folder(
                                    $this->get_regular_folder_items($user_input->parent_media_url, 0, $plugin_cookies), true);
                    break;
            }
        }
        // ActionFactory::open_folder($user_input->selected_media_url);
        return array
            (
            GuiAction::handler_string_id => PLUGIN_OPEN_FOLDER_ACTION_ID,
            GuiAction::data => array(
                'media_url' => $user_input->selected_media_url
                    )
             );
    }
    ///////////////////////////////////////////////////////////////////////


    protected function add_text_field(&$defs, $name, $title, $initial_value, $numeric, $password, $has_osk, $always_active, $width, $need_confirm = false, $need_apply = false) {
        ControlFactory::add_text_field($defs, $this, null,
                        $name, $title, $initial_value,
                        $numeric, $password, $has_osk, $always_active, $width,
                        $need_confirm, $need_apply);
    }

    ///////////////////////////////////////////////////////////////////////
    protected function add_combobox(&$defs, $name, $title, $initial_value, $value_caption_pairs, $width, $need_confirm = false, $need_apply = false)
    {
        ControlFactory::add_combobox($defs, $this, null,
                        $name, $title, $initial_value, $value_caption_pairs, $width,
                        $need_confirm, $need_apply);
    }

    protected function add_button(&$defs,$name, $title, $caption, $width)
    {
        ControlFactory::add_button($defs, $this, null,
            $name, $title, $caption, $width);
    }

    ///////////////////////////////////////////////////////////////////////
   

public function do_get_control_defs(&$plugin_cookies)
    {
        $defs = array();

       

 $main_icon = isset($plugin_cookies->main_icon) ? $plugin_cookies->main_icon : 'yes';
       

 $use_osk = isset($plugin_cookies->use_osk) ? $plugin_cookies->use_osk : 'yes';
        

$skip_details = isset($plugin_cookies->skip_details) ? $plugin_cookies->skip_details : 'no';
 

       $video_quality = isset($plugin_cookies->video_quality) ? $plugin_cookies->video_quality : 1;


		$video_poisk = isset($plugin_cookies->video_poisk) ? $plugin_cookies->video_poisk : 1;


		$video_sorting = isset($plugin_cookies->video_sorting) ? $plugin_cookies->video_sorting : 1;


		$video_production = isset($plugin_cookies->video_production) ? $plugin_cookies->video_production : 1;
	

	$video_language = isset($plugin_cookies->video_language) ? $plugin_cookies->video_language : 1;


		$video_resolution = isset($plugin_cookies->video_resolution) ? $plugin_cookies->video_resolution : 1;
       

 $buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;





		

$user_login = isset($plugin_cookies->user_login) ? $plugin_cookies->user_login : '';
	

$user_password = isset($plugin_cookies->user_password) ? $plugin_cookies->user_password : '';



	



	
        $vquality = $this->get_quality_array(true);
		

$vpoisk = $this->get_poisk_array(true);
		

$vsorting = $this->get_sorting_array(true);
		

$vproduction = $this->get_production_array(true);
       

 $vlanguage = $this->get_language_array(true);
		

$vresolution = $this->get_resolution_array(true);
		
      

  $show_ops = array();
       

 if (is_interface_language_russian_or_similar ()) {
            $show_ops['yes'] = 'Да';
            $show_ops['no'] = 'Нет';
        } 

else {
            $show_ops['yes'] = 'Yes';
            $show_ops['no'] = 'No';
        }
 
 


      

 $this->add_text_field($defs,
                    'user_login',
                    'login',
                    $user_login, 0, 0, 0, 1, 400, 0, true
            );

 

 $this->add_text_field($defs,
                    'user_password',
                    'password',
                    $user_password, 0, 0, 0, 1, 400, 0, true
            );

 



      

 $show_buf_time_ops = array();
        
        $show_buf_time_ops[0] = '0.0 с.';
		$show_buf_time_ops[500] = '0.5 с.';
        $show_buf_time_ops[1000] = '1 с.';
        $show_buf_time_ops[2000] = '2 с.';
        $show_buf_time_ops[3000] = '3 с.';
        $show_buf_time_ops[5000] = '5 с.';
        $show_buf_time_ops[10000] = '10 с.';


        $this->add_combobox
        (
            $defs,
            'buf_time',
            'Буферизация:',
            $buf_time, $show_buf_time_ops, 0, true
        );
        $skin_ops = array();

        $skin_ops['default'] = 'По умолчанию';
        $skin_ops['juniperus'] = 'От Juniperus (Пиратская тема)';

        $skin = isset($plugin_cookies->skin) ? $plugin_cookies->skin : 'default';
        $this->add_combobox
        (
            $defs,
            'skin',
            'Оформление (требуется перезагрузка):',
            $skin, $skin_ops, 0, true
        );

        $this->add_button
        (
            $defs,
            'restart',
            '',
            'Перезагрузить плеер',
            0
        );
		
		



    return $defs;
    }

 






   ///////////////////////////////////////////////////////////////////////
    public function do_get_search_defs(&$plugin_cookies)
    {
        $defs = array();
        $search_text = isset($plugin_cookies->search) ? $plugin_cookies->search : '';
        $use_osk = isset($plugin_cookies->use_osk) ? $plugin_cookies->use_osk : 'yes';
        $this->add_text_field($defs,
                'search', "",
                $search_text, 0, 0,
                ($use_osk === 'yes' ? 1 : 0),
                true, 1300, 0, true
        );
        if ($use_osk === 'yes')
            ControlFactory::add_vgap($defs, 500);
        else
            ControlFactory::add_vgap($defs, 50);

        $do_new_search_action = UserInputHandlerRegistry::create_action($this, 'do_new_search');

        ControlFactory::add_custom_close_dialog_and_apply_buffon($defs,'apply_subscription',
                (is_interface_language_russian_or_similar() ? 'Искать' : 'Search'),
                300, $do_new_search_action);
        ControlFactory::add_close_dialog_button($defs,
                'Отмена', 300);

        return $defs;
    }

    ///////////////////////////////////////////////////////////////////////
    public function get_handler_id()
    {
        return self::ID;
    }

    ///////////////////////////////////////////////////////////////////////
    public function get_next_folder_view($media_url, &$plugin_cookies)
    {
        //hd_print('get_next_folder_view');
        $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
        if ($view_type == 3)
            $view_type = 1;
        else
            ++$view_type;
            
        $plugin_cookies->view_type = $view_type;
        
        return $this->get_folder_view($media_url, $plugin_cookies); 
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_folder_view($media_url, &$plugin_cookies)
    {
	    //hd_print('--->>> get_folder_view --->>>' . $media_url);

	    if ($media_url === 'main_menu')
	    {
            return  array
                    (
                        PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                        PluginFolderView::multiple_views_supported  => false,
                        PluginFolderView::data                      => array
                        (
                            PluginRegularFolderView::async_icon_loading => false,
                            PluginRegularFolderView::initial_range =>
                                $this->get_main_menu_items($media_url, $plugin_cookies),
                            PluginRegularFolderView::view_params => self::get_main_menu_folder_view($plugin_cookies),
                            PluginRegularFolderView::base_view_item_params => self::get_main_vip($plugin_cookies),
                            PluginRegularFolderView::not_loaded_view_item_params => array(),
                            PluginRegularFolderView::actions => $this->get_main_menu_action_map($media_url, $plugin_cookies)
                        )
                    );
	    }
        else if 
	    (
		    $media_url === 'main_menu:videos' ||
			$media_url === 'main_menu:genres' ||
			$media_url === 'main_menu:audio' ||
		    $media_url === 'main_menu:search'
	    )
        {
		    switch ($media_url) 
		    {
                    case 'main_menu:search':
                        $actions = $this->get_search_action_map($media_url, $plugin_cookies);
                        break;
                    case 'main_menu:videos':
                        $actions = $this->get_video_action_map($media_url, $plugin_cookies);
                        break;
					case 'main_menu:genres':
                        $actions = $this->get_video_action_map($media_url, $plugin_cookies);
                        break;
					case 'main_menu:audio':
                        $actions = $this->get_video_action_map($media_url, $plugin_cookies);
                        break;
		    }

            return  array
                    (
                        PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                        PluginFolderView::multiple_views_supported  => false,
                        PluginFolderView::data                      => array
                        (
                            PluginRegularFolderView::async_icon_loading => false,
                            PluginRegularFolderView::initial_range =>
                                $this->get_main_menu_items($media_url, $plugin_cookies),
                            PluginRegularFolderView::view_params => array
                            (
                                ViewParams::num_cols => 1,
                                ViewParams::num_rows => 12
                            ),
                            PluginRegularFolderView::base_view_item_params => self::$catalog_vip,
                            PluginRegularFolderView::not_loaded_view_item_params => array(),
                            PluginRegularFolderView::actions => $actions
                        )
                    );
	    }


	   





 elseif ($media_url === 'setup')
	    {
                $defs = $this->do_get_control_defs($plugin_cookies);
                $folder_view = array
                    (
                	    PluginControlsFolderView::defs => $defs,
                	    PluginControlsFolderView::initial_sel_ndx => -1,
            	    );
                return array
                    (
                	    PluginFolderView::multiple_views_supported => false,
	                    PluginFolderView::archive => null,
        	            PluginFolderView::view_kind => PLUGIN_FOLDER_VIEW_CONTROLS,
                	    PluginFolderView::data => $folder_view,
            	    );
            }

         $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
         HD::decode_user_data($media_url, $media_str, $user_data);

         if
         (

            HD::has_attribute($user_data, 'category_ref')

         )
         {
             if (HD::has_attribute($user_data, 'ser_feed'))
             {
                $actions = $this->get_item_action_map($media_url, $plugin_cookies);
                $not_loaded_item = self::$catalog_vip;
             }
            




 else if ($media_url === 'main_menu:fav')
             {
                $actions = $this->get_fav_action_map($media_url, $plugin_cookies);
                $not_loaded_item = self::$catalog_vip;
             }
             else
             {
                $actions = $this->get_video_action_map($media_url, $plugin_cookies);
                $not_loaded_item = array();
             }

            return  array
                    (
                        PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                        PluginFolderView::multiple_views_supported  => false,
                        PluginFolderView::data                      => array
                        (
                            PluginRegularFolderView::async_icon_loading => false,
                            PluginRegularFolderView::initial_range =>
                                $this->get_regular_folder_items($media_url, 0, $plugin_cookies),
                            PluginRegularFolderView::view_params => array
                            (
                                ViewParams::num_cols => 1,
                                ViewParams::num_rows => 12
                            ),
                            PluginRegularFolderView::base_view_item_params => self::$catalog_vip,
                            PluginRegularFolderView::not_loaded_view_item_params => $not_loaded_item,
                            PluginRegularFolderView::actions => $actions
                        )
                    );
         }
         else if 
         (
            $media_url === 'main_menu:fav' ||
            HD::has_attribute($user_data, 'subcategory_ref') ||
            HD::has_attribute($user_data, 'ser_feed')
         )
         {

             if ($media_url === 'main_menu:fav')
             {
                $actions = $this->get_fav_action_map($media_url, $plugin_cookies);
             }
             else
             {
                $actions = $this->get_item_action_map($media_url, $plugin_cookies);
             }

            return array(
                PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                PluginFolderView::multiple_views_supported  => true,
                PluginFolderView::data                      => array(
                    PluginRegularFolderView::async_icon_loading => true,
                    PluginRegularFolderView::initial_range =>
                        $this->get_loading_items($plugin_cookies),

                    PluginRegularFolderView::view_params => array(
                        ViewParams::num_cols => ($view_type == 1 ? 5 : 1),
                        ViewParams::num_rows => ($view_type == 1 ? 2 : ($view_type == 2 ? 3 : ($view_type == 4 ? 1 : 10))),
                        ViewParams::paint_details => ($view_type == 4 ? false : true),
                        ViewParams::zoom_detailed_icon => true,
                        ViewParams::paint_item_info_in_details => true,
                        ViewParams::item_detailed_info_font_size => FONT_SIZE_NORMAL,// FONT_SIZE_SMALL,
                        
                        ViewParams::paint_sandwich => (($view_type == 1 || $view_type == 4) ? true : false),
                        ViewParams::sandwich_base => 'gui_skin://special_icons/sandwich_base.aai',
                        ViewParams::sandwich_mask => 'cut_icon://{name=sandwich_mask}',
                        ViewParams::sandwich_cover => 'cut_icon://{name=sandwich_cover}',
                        ViewParams::sandwich_width => 190,
                        ViewParams::sandwich_height => 290,
                        ViewParams::sandwich_icon_upscale_enabled => true,
                        ViewParams::sandwich_icon_keep_aspect_ratio => true,
                    ),

                    PluginRegularFolderView::base_view_item_params => array(
                        ViewItemParams::item_paint_icon => true,
                        ViewItemParams::icon_sel_scale_factor =>1.2,
                        ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                        ViewItemParams::item_layout => HALIGN_LEFT,
                        ViewItemParams::icon_valign => VALIGN_CENTER,
                        ViewItemParams::icon_dx => 10,
                        ViewItemParams::icon_dy => -5,
                        ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : ($view_type == 4 ? 250 : 50))),
                        ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : ($view_type == 4 ? 350 : 50))),
                        ViewItemParams::icon_sel_margin_top => 0,
                        ViewItemParams::item_paint_caption => ($view_type == 1 ? false : true),
                        ViewItemParams::item_caption_width => ($view_type == 2 ? 950 : 1100)
                    ),

                    PluginRegularFolderView::not_loaded_view_item_params => array(
                        ViewItemParams::item_paint_icon => true,
                        ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : 50)),
                        ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : 50)),
                        ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai')
                    ),

                    PluginRegularFolderView::actions => $actions
                )
            );
         }
         else if
         (
            HD::has_attribute($user_data, 'season_ref') &&
            !HD::has_attribute($user_data, 'info')
         )
         {
                if (isset($plugin_cookies->fav_items))
                $isfav = ListUtil::is_in_list($plugin_cookies->fav_items, $user_data->season_ref);

            
            if ($isfav)
            {
                    $add_action = UserInputHandlerRegistry::create_action(
                                $this, 'mark_viewed');
                    $add_action['caption'] = (
                                is_interface_language_russian_or_similar() ? 'Просмотрено/Не просмотрено' : "Mark as viewed/not viewed"
                            );
					$aria_inf = UserInputHandlerRegistry::create_action(
								$this, 'aria_inf');
					$aria_inf['caption'] = (
								is_interface_language_russian_or_similar() ? 'Информация о закачке (aria)' : "aria"
							);	
					$aria_download = UserInputHandlerRegistry::create_action(
								$this, 'aria_download');
					$aria_download['caption'] = (
								is_interface_language_russian_or_similar() ? 'Скачать файл (aria)' : "aria_download"
							);	
                $actions = array
                    (
                        GUI_EVENT_KEY_ENTER => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                        GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                        GUI_EVENT_KEY_B_GREEN => $add_action,
						GUI_EVENT_KEY_D_BLUE => $aria_inf,
						GUI_EVENT_KEY_C_YELLOW => $aria_download
                    );
            }
            else
            {
					    $add_action = UserInputHandlerRegistry::create_action(
                                $this, 'mark_viewed');
						$add_action['caption'] = (
                                is_interface_language_russian_or_similar() ? 'Просмотрено/Не просмотрено' : "Mark as viewed/not viewed"
                            );
						$aria_inf = UserInputHandlerRegistry::create_action(
									$this, 'aria_inf');
						$aria_inf['caption'] = (
									is_interface_language_russian_or_similar() ? 'Информация о закачке (aria)' : "aria"
								);	
						$aria_download = UserInputHandlerRegistry::create_action(
									$this, 'aria_download');
						$aria_download['caption'] = (
									is_interface_language_russian_or_similar() ? 'Скачать файл (aria)' : "aria_download"
								);	
				$actions = array
                (
						GUI_EVENT_KEY_ENTER => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                        GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action
						GUI_EVENT_KEY_B_GREEN => $add_action,
						GUI_EVENT_KEY_D_BLUE => $aria_inf,
						GUI_EVENT_KEY_C_YELLOW => $aria_download
                );
            }

            return array
            (
                PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                PluginFolderView::multiple_views_supported  => false,
                PluginFolderView::data                      => array(
                    PluginRegularFolderView::async_icon_loading => true,
                    PluginRegularFolderView::initial_range =>
                        $this->get_regular_folder_items($media_url, 0, $plugin_cookies),

                    PluginRegularFolderView::view_params => array(
                        ViewParams::num_cols => 1,
                        ViewParams::num_rows => 10,
                        ViewParams::paint_details => false,
                    ),

                    PluginRegularFolderView::base_view_item_params => array(
                        ViewItemParams::item_paint_icon => true,
                        ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                    ViewItemParams::item_layout => HALIGN_LEFT,
                       ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::icon_dx => 20,
                    ViewItemParams::icon_dy => -5,
                    ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
                    ViewItemParams::item_caption_width => 1550
                    ),

                    PluginRegularFolderView::not_loaded_view_item_params => array(),

                    PluginRegularFolderView::actions => $actions
                )
            );
         }
         
         if (HD::has_attribute($user_data, 'info'))
         {
            $c = $this->parse_season_info($user_data->video_id);
            HD::decode_user_data($c, $media_str, $user_data);

            $movie = array(
                PluginMovie::name => $user_data->title,
                PluginMovie::name_original => $user_data->name_original,
                PluginMovie::description => $user_data->description,
                PluginMovie::poster_url => $user_data->video_image_url,
                PluginMovie::length_min => $user_data->duration_min,
                PluginMovie::year => $user_data->year,
                PluginMovie::directors_str => $user_data->director,
                PluginMovie::scenarios_str => '',
                PluginMovie::actors_str => $user_data->actors,
                PluginMovie::genres_str => $user_data->genre,
                PluginMovie::rate_imdb => $user_data->imdb_rating,
                PluginMovie::rate_kinopoisk => $user_data->kp_rating,
                PluginMovie::rate_mpaa => '',
                PluginMovie::country => $user_data->country,
                PluginMovie::budget => ''
                );
                

            $from_fav = false;
            $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
            if (ListUtil::is_in_list($fav_items, $user_data->video_id))
                $from_fav = true;
                
            if ($from_fav)
            {
                $right_button_action = UserInputHandlerRegistry::create_action(
                            $this, 'remove_fav');
                $right_button_action['caption'] = (
                            is_interface_language_russian_or_similar() ? "Удалить из Избранного" : 'Remove from Favorites'
                        );
            }
            else
            {
                $right_button_action = UserInputHandlerRegistry::create_action(
                            $this, 'add_favorite');
                $right_button_action['caption'] = (
                            is_interface_language_russian_or_similar() ? 'Добавить в Избранное' : "Add Favorite"
                        );
            }


            $right_button_caption = $right_button_action['caption'];
            
            $movie_folder_view = array
            (
                PluginMovieFolderView::movie => $movie,
                PluginMovieFolderView::has_right_button => true,
                PluginMovieFolderView::right_button_caption => $right_button_caption,
                PluginMovieFolderView::right_button_action => $right_button_action,
                PluginMovieFolderView::has_multiple_series => ($user_data->n_series > 1),
                PluginMovieFolderView::series_media_url => HD::encode_user_data(
                                                                array(
                                                                    'season_ref' => $user_data->video_id,
                                                                    'season_title' => $user_data->title,
                                                                    'n_series' => $user_data->n_series,
                                                                )
                                                           ),												  
													   
			 PluginMovieFolderView::params => array
            (			               
				PluginFolderViewParams::paint_path_box =>true,
                PluginFolderViewParams::paint_content_box_background => true,
               	PluginFolderViewParams::background_url => $user_data->video_image_url_b
            )
			
            );

             return array
                (
                    PluginFolderView::multiple_views_supported => false,
                    PluginFolderView::archive => null,
                    PluginFolderView::view_kind => PLUGIN_FOLDER_VIEW_MOVIE,
                    PluginFolderView::data => $movie_folder_view
                );
         }
         else if (HD::has_attribute($user_data, 'video_id'))
         {
	        $isfav = ListUtil::is_in_list($plugin_cookies->fav_items, $user_data->video_id);
            
            if ($isfav)
            {
                    $add_action = UserInputHandlerRegistry::create_action(
                                $this, 'mark_viewed');
                    $add_action['caption'] = (
                                is_interface_language_russian_or_similar() ? 'Просмотрено/Не просмотрено' : "Mark as viewed/not viewed"
                            );
					$aria_inf = UserInputHandlerRegistry::create_action(
								$this, 'aria_inf');
					$aria_inf['caption'] = (
								is_interface_language_russian_or_similar() ? 'Информация о закачке (aria)' : "aria"
							);	
					$aria_download = UserInputHandlerRegistry::create_action(
								$this, 'aria_download');
					$aria_download['caption'] = (
								is_interface_language_russian_or_similar() ? 'Скачать файл (aria)' : "aria_download"
							);			
                $actions = array
                    (
                        GUI_EVENT_KEY_ENTER => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                        GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                        GUI_EVENT_KEY_B_GREEN => $add_action,
						GUI_EVENT_KEY_D_BLUE => $aria_inf,
						GUI_EVENT_KEY_C_YELLOW => $aria_download
                    );
            }
            else
            {
					    $add_action = UserInputHandlerRegistry::create_action(
                                $this, 'mark_viewed');
						$add_action['caption'] = (
                                is_interface_language_russian_or_similar() ? 'Просмотрено/Не просмотрено' : "Mark as viewed/not viewed"
                            );
						$aria_inf = UserInputHandlerRegistry::create_action(
									$this, 'aria_inf');
						$aria_inf['caption'] = (
									is_interface_language_russian_or_similar() ? 'Информация о закачке (aria)' : "aria"
								);	
						$aria_download = UserInputHandlerRegistry::create_action(
									$this, 'aria_download');
						$aria_download['caption'] = (
									is_interface_language_russian_or_similar() ? 'Скачать файл (aria)' : "aria_download"
								);	
				$actions = array
                (
						GUI_EVENT_KEY_ENTER => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action,
                        GUI_EVENT_KEY_PLAY => $this->get_play_action($media_url, $plugin_cookies),//self::$vod_play_action
						GUI_EVENT_KEY_B_GREEN => $add_action,
						GUI_EVENT_KEY_D_BLUE => $aria_inf,
						GUI_EVENT_KEY_C_YELLOW => $aria_download
                );
            }
            
            return array(
                PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                PluginFolderView::multiple_views_supported  => false,
                PluginFolderView::data                      => array(
                    PluginRegularFolderView::async_icon_loading => true,
                    PluginRegularFolderView::initial_range =>
                        $this->get_regular_folder_items($media_url, 0, $plugin_cookies),

                    PluginRegularFolderView::view_params => array(
                        ViewParams::num_cols => 1,
                        ViewParams::num_rows => 10,
                        ViewParams::paint_details => false,
   
                    ),

                    PluginRegularFolderView::base_view_item_params => array(
                        ViewItemParams::item_paint_icon => true,
                        ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
	                ViewItemParams::item_layout => HALIGN_LEFT,
       		        ViewItemParams::icon_valign => VALIGN_CENTER,
        	        ViewItemParams::icon_dx => 20,
        	        ViewItemParams::icon_dy => -5,
        	        ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
        	        ViewItemParams::item_caption_width => 1550
                    ),

                    PluginRegularFolderView::not_loaded_view_item_params => array(),

                    PluginRegularFolderView::actions => $actions
                )
            );
         }

	    if ($media_url === 'main_menu:fav')
            $actions = $this->get_fav_action_map($media_url, $plugin_cookies);
	    else
	        $actions = $this->get_item_action_map($media_url, $plugin_cookies);

        return array(
            PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
            PluginFolderView::multiple_views_supported  => true,
            PluginFolderView::data                      => array(
                PluginRegularFolderView::async_icon_loading => true,
                PluginRegularFolderView::initial_range =>
                    $this->get_loading_items($plugin_cookies),

                PluginRegularFolderView::view_params => array(
                    ViewParams::num_cols => ($view_type == 1 ? 5 : 1),
                    ViewParams::num_rows => ($view_type == 1 ? 2 : ($view_type == 2 ? 3 : 10)),
                    ViewParams::paint_details => true,
                    ViewParams::zoom_detailed_icon => true,
                    ViewParams::paint_item_info_in_details => true,
//                    ViewParams::detailed_icon_scale_factor => 0.5,
                    ViewParams::item_detailed_info_font_size => FONT_SIZE_NORMAL,// FONT_SIZE_SMALL,
                    
                    ViewParams::paint_sandwich => ($view_type == 1 ? true : false),
                    ViewParams::sandwich_base => 'gui_skin://special_icons/sandwich_base.aai',
                    ViewParams::sandwich_mask => 'cut_icon://{name=sandwich_mask}',
                    ViewParams::sandwich_cover => 'cut_icon://{name=sandwich_cover}',
                    ViewParams::sandwich_width => 190,
                    ViewParams::sandwich_height => 290,
                    ViewParams::sandwich_icon_upscale_enabled => true,
                    ViewParams::sandwich_icon_keep_aspect_ratio => true,

//                    ViewParams::item_detailed_info_rel_y => 560
                ),

                PluginRegularFolderView::base_view_item_params => array(
                    ViewItemParams::item_paint_icon => true,
//                    ViewItemParams::icon_scale_factor =>0.75,
                    ViewItemParams::icon_sel_scale_factor =>1.2,
                    ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                    ViewItemParams::item_layout => HALIGN_LEFT,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::icon_dx => 10,
                    ViewItemParams::icon_dy => -5,
                    ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : 50)),
                    ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : 50)),
                    ViewItemParams::icon_sel_margin_top => 0,
                    ViewItemParams::item_paint_caption => ($view_type == 1 ? false : true),
                    ViewItemParams::item_caption_width => ($view_type == 2 ? 950 : 1100)
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array(
                    ViewItemParams::item_paint_icon => true,
                    ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : 50)),
                    ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : 50)),
                    ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai')
                ),

                PluginRegularFolderView::actions => $actions
            )
        );

        throw new Exception('Unknown media url');
    }

    ///////////////////////////////////////////////////////////////////////
  


  private function parse_season_info($season_ref)
    {
        //hd_print("--> parse season info: started...");
        $api = HOST_API_URL;     
        $items = array();
       
$url = $season_ref;




        
        



$user_login = isset($plugin_cookies->user_login) ? $plugin_cookies->user_login : 1;
	

$user_password = isset($plugin_cookies->user_password) ? $plugin_cookies->user_password : 1;






$post =  "LoginForm[username]=".$user_login."&LoginForm[password]=".$user_password."&LoginForm[rememberMe]=1&yt0=Войти";

$ch = curl_init();
curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
curl_setopt($ch, CURLOPT_URL, $url);
curl_setopt($ch, CURLOPT_COOKIEJAR, "c.txt");
curl_setopt($ch, CURLOPT_FAILONERROR, true);
curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);

curl_setopt($ch, CURLOPT_REFERER, $url);
//curl_setopt($ch, CURLOPT_AUTOREFERER, true);
curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
curl_setopt($ch, CURLOPT_TIMEOUT, 60);
curl_setopt($ch, CURLOPT_POST, 1);
curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
curl_setopt($ch, CURLOPT_COOKIEFILE,"c.txt");

 $doc = curl_exec($ch);

curl_close($ch);




//info_block

$tmp = explode('<meta property="og:title"',$doc);


 $info_block = strstr($tmp[1], 'content="application/x-shockwave-flash" />', true);




        
        // title
        $tmp = explode("<h3>", $doc);


       echo $video_title = str_remove_spec(strstr($tmp[1], "</h3>", true));




        
        // image
       

       echo $video_image = 'http://nogomya.ch/images/logo.png';






                // description
        $description = '';
 

$tmp = explode("Сейчас в эфире", $doc);


      $blok_des = strstr($tmp[1], "<footer>", true);


       

$tmp = explode('<a href="', $blok_des);



 
           $tmp = $tmp[1].'  '.$tmp[2].'  '.$tmp[3].'  '.$tmp[4].'  '.$tmp[5].'  '.$tmp[6].'  '.$tmp[7];


$description = str_replace("/","",str_remove_spec($tmp));
			

 echo $description = str_replace("'>","",strip_tags($description));
          

// hd_print("--->>> $description");



        
       // year
  

$tmp = "";
                $year = '';
        

$tmp = explode('Дата выхода фильма:</b><!--colorend--></span><!--/colorend-->', $info_block);
       

if (count($tmp) > 1)
           

$year = strstr($tmp[1], '<', true);
        


echo $year = strip_tags($year);
        // // hd_print("year--->>> $year");

        





              // country
      

 $country = '';
       

 $tmp = explode('Страна:</b><!--colorend--></span><!--/colorend--> ', $info_block);
        

if (count($tmp) > 1)
           

 $country = str_remove_spec(strstr($tmp[1], '<', true));
			

echo $country = strip_tags($country);
         // // hd_print("--->>> $country");

 

       

            // genre
        

$genre = '';
		$tmp = explode('Жанр:</b><!--colorend--></span><!--/colorend-->', $info_block);

if (count($tmp) > 1)
       

$genre = str_remove_spec(strstr($tmp[1], '<', true));
		

echo $genre = strip_tags($genre);
		 // // hd_print("--->>> $genre");


        
        

           // duration
       

$tmp = explode('Продолжительность:</b><!--colorend--></span><!--/colorend-->', $info_block);
       

$duration_min = 0;
       $duration = '';
      

if (count($tmp) > 1)
		{
 

$duration_min = strstr($tmp[1], '<', true);
			

echo $duration = "$duration_min мин.";

		
}
        
		

 // // hd_print("--->>> $duration");



 
      
            // director
        

$director = '';
        $tmp = explode('Режиссер:</b><!--colorend--></span><!--/colorend-->', $info_block);
        

if (count($tmp) > 1)
        $director = str_remove_spec(strstr($tmp[1], '<', true));
		

echo $director = strip_tags($director);
         // // hd_print("--->>> $director");


            
       

           // actors
        

$actors = '';
        $tmp = explode('В ролях:</b><!--colorend--></span><!--/colorend-->', $info_block);

        
if (count($tmp) > 1)
 
           
$actors = str_remove_spec(strstr($tmp[1], '<', true));

       
echo $actors = strip_tags($actors);
        // hd_print("--->>> $actors");



       //name_original

$name_original = '';

$tmp = explode('Полное название:</b><!--colorend--></span><!--/colorend--> <b>', $info_block);


if (count($tmp) > 1)

echo $name_original = str_remove_spec(strstr($tmp[1], "<", true));



		


$tmp = explode('http://www.kinopoisk.ru/rating/', $info_block);
        if (count($tmp) > 1)
			
        $kinopoisk_link = str_remove_spec(strstr($tmp[1], '.gif', true));
		$kinopoisk_link = 'http://www.kinopoisk.ru/rating/' . $kinopoisk_link .'.xml';
		//hd_print("kinopoisk_link--->>> $kinopoisk_link");
		$kinopoisk_link = str_replace('http://www.kinopoisk.ru/rating/.xml">','http://www.kinopoisk.ru/rating/1.xml',$kinopoisk_link);
		//$docy = file_get_contents($kinopoisk_link);
		//hd_print("docy--->>> $docy");
		


         //kp_rating
		

$kp_rating = '';
		      

$tmp = explode('Бюджет:</b><!--colorend--></span><!--/colorend--> <!--colorstart:#ffcc99--><span style="color:#ffcc99"><!--/colorstart-->', $info_block);
        if (count($tmp) > 1)
           

echo $kp_rating = str_remove_spec(strstr($tmp[1], '<', true));
			

		

//hd_print("kp_rating--->>> $kp_rating");


		

     //imdg_rating

$imdb_rating = '';


$tmp = explode('Бюджет:</b><!--colorend--></span><!--/colorend--> <!--colorstart:#ffcc99--><span style="color:#ffcc99"><!--/colorstart-->', $info_block);
        if (count($tmp) > 1)


echo $imdb_rating = str_remove_spec(strstr($tmp[1], '<', true));


//hd_print("imdb_rating--->>> $imdb_rating");


		
        

       // number of series
        

$videos = explode('<iframe', $info_block);
        unset($videos[0]);
 
       
$videos = array_values($videos);
        $n_series = count($videos);

         // // hd_print("--->>> $n_series");

       

      



  return  HD::encode_user_data
                (
                    array
                    (
                        'video_id' => $season_ref,
                        'n_series' => $n_series,
                        'page_ref' => $season_ref,
                        'video_image_url' => $video_image,
                        'title' => $video_title,
                        'genre' => str_remove_spec($genre),
                        'country' => str_remove_spec($country),
                        'year' => str_remove_spec($year),
                        'duration' => str_remove_spec($duration),
                        'duration_min' => $duration_min,
                        'director' => str_remove_spec($director),
                        'actors' => str_remove_spec($actors),
                        'description' => str_remove_spec($description),
						'name_original' => $name_original,
                        'video_image_url_b' => $video_image_b,
                        'kp_rating' => $kp_rating,
						'imdb_rating' => $imdb_rating,
                    )
                );
    }
   





 ///////////////////////////////////////////////////////////////////////

    




private function parse_season($season_ref, &$plugin_cookies)
    {
        $api = HOST_API_URL;     
        $items = array();
        $url = $season_ref;
        
       




$user_login = isset($plugin_cookies->user_login) ? $plugin_cookies->user_login : 1;
	

$user_password = isset($plugin_cookies->user_password) ? $plugin_cookies->user_password : 1;






$post =  "LoginForm[username]=".$user_login."&LoginForm[password]=".$user_password."&LoginForm[rememberMe]=1&yt0=Войти";

$ch = curl_init();
curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
curl_setopt($ch, CURLOPT_URL, $url);
curl_setopt($ch, CURLOPT_COOKIEJAR, "c.txt");
curl_setopt($ch, CURLOPT_FAILONERROR, true);
curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);

curl_setopt($ch, CURLOPT_REFERER, $url);
//curl_setopt($ch, CURLOPT_AUTOREFERER, true);
curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
curl_setopt($ch, CURLOPT_TIMEOUT, 60);
curl_setopt($ch, CURLOPT_POST, 1);
curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
curl_setopt($ch, CURLOPT_COOKIEFILE,"c.txt");

 $doc = curl_exec($ch);

curl_close($ch);




//info_block

$tmp = explode('<meta property="og:title"',$doc);


 $info_block = strstr($tmp[1], 'content="application/x-shockwave-flash" />', true);




        
        // title
        $tmp = explode("<h3>", $doc);


       echo $video_title = str_remove_spec(strstr($tmp[1], "</h3>", true));




        
        // image
       

       echo $video_image = 'http://nogomya.ch/images/logo.png';






                // description
        $description = '';
 

$tmp = explode("Сейчас в эфире", $doc);


      $blok_des = strstr($tmp[1], "<footer>", true);


       

$tmp = explode('<a href="', $blok_des);



 
              $tmp = $tmp[1].'  '.$tmp[2].'  '.$tmp[3].'  '.$tmp[4].'  '.$tmp[5].'  '.$tmp[6].'  '.$tmp[7];


$description = str_replace("/","",str_remove_spec($tmp));
			

 echo $description = str_replace("'>","",strip_tags($description));
          

// hd_print("--->>> $description");
            



$tmp = explode('"file":"rtmp', $doc);

echo $episode_ref = 'http://ts://127.0.0.1:81/cgi-bin/rtmp.sh?-r rtmp'.
strstr($tmp[1], '"', true);   

 // hd_print("--->>> hepisode_ref: $episode_ref");
		




$episode_title = $video_title;
   
      
echo $episode_title = strip_tags($episode_title);
  // // hd_print("--->>> pepisode_title: $episode_title");

        


   array_push
                (
                    $items,
                    HD::encode_user_data
                    (
                        array
                        (
                            //{ Viewed items
                            'episode_title' => str_remove_spec(($is_new ? '[NEW] ' : ($is_viewed ? '[VIEWED] ' : '')) . $episode_title),
                            //} Viewed items
                            'episode_ref' => str_remove_spec($episode_ref),
                            'season_title' => $video_title,
                            'season_ref' => str_remove_spec($season_ref),
                            'ndx_series' => $ndx_series,
                            'poster_url' => str_remove_spec($video_image),
                            'description' => str_remove_spec($description),
                        )
                    )
                );
                ++$this->m_items_count;
                ++$ndx_series;
            
     
		return $items;
		
    }
    ///////////////////////////////////////////////////////////////////////
   






 private function get_next_fav(&$plugin_cookies)
    {
        
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
        
        $ref = "";
        
        $n = 0;
        foreach (ListUtil::string_to_list($fav_items) as $item)
        {
            if ($item == "")
                continue;
            
            if ($n == $this->m_feed)
            {
                $ref = $item;
            }

            ++$n;
            
        }

        if ($ref == "")
            return false;
        
        $items = array();

        $c = VideoCache::get($ref);
        if (!is_null($c))
        {
            array_push
            (
                $items,
                $c
            );

            ++$this->m_items_count;

            return $items;
            
        }

        $api = HOST_API_URL;
        
        $url = $api . $ref;
        
        $doc = HD::http_get_document($url);
        
        $tmp = strstr($doc, '<div class="l-content  ">');
        $info_block = strstr($tmp, '<div class="b-filelist"></div>', true);
        
        // title
        $info_block = str_replace('<b class="b-subcategory-title">Клипы</b>', '" alt="', $info_block);
		$info_block = str_replace('<b class="b-subcategory-title">777Клипы</b>', '" alt="', $info_block);
		$info_block = str_replace('    </h1>', '"/>', $info_block);
		$tmp = explode('" alt="', $info_block);
        $season_title = str_remove_spec(strstr($tmp[1], '"/>', true));
        
        // image
		$info_block = str_replace("url: 'http://", '<img src="http://', $info_block);//Vokir
		$info_block = str_replace(".jpg'", '.jpg"', $info_block);//Vokir
		$tmp = explode('<img src="', $info_block);
        $season_image = str_remove_spec(strstr($tmp[1], '"', true));
		$season_image = str_replace('/6/', '/1/', $season_image);  //Vokir
		$season_image = str_replace('/5/', '/1/', $season_image);  //Vokir
		$season_image = str_replace('/9/', '/1/', $season_image);  //Vokir
        $series_block = '';
        $tmp = strstr($doc, '<select size="1" name="fileId" onchange="this.form. submit();">');
        
        $is_has_new = false;

        if ($tmp && isset($plugin_cookies->$ref))
        {
            $series_block = strstr($tmp, '</select>', true);
            $videos = explode('value="', $series_block);
            unset($videos[0]);
            $videos = array_values($videos);

            foreach($videos as $video)
            {
                $fileid = strstr($video, '"', true);
                $episode_ref = $url . "?fileId=$fileid";
                
            //    hd_print("--->>> episode_ref: $episode_ref");

                if (isset($plugin_cookies->$ref))
                    if (!ListUtil::is_in_list($plugin_cookies->$ref, $episode_ref))
                        $is_has_new = true;
                            
                if ($is_has_new)
                    break;
            }
        }
        
        array_push
        (
            $items,
            HD::encode_user_data
            (
                array
                (
                    'video_id' => $ref,
                    'season_title' => $season_title,
                    'season_ref' => $ref,
                    'season_image' => $season_image,
                    'is_has_new' => $is_has_new
                )
            )
        );

        ++$this->m_items_count;

        return $items;
    }
    ///////////////////////////////////////////////////////////////////////
    public function get_regular_folder_items($media_url, $from_ndx, &$plugin_cookies)
    {
	    //hd_print("--> get_regular_folder_items(): starting." . $media_url);
        if 
	    (
		    $media_url === 'main_menu' ||
		    $media_url === 'main_menu:videos' ||
			$media_url === 'main_menu:genres' ||
		    $media_url === 'main_menu:audio' ||
		    $media_url === 'main_menu:search' ||
		    $media_url === 'main_menu:fav' && isset($plugin_cookies->dynamic_fav_off)

	    )
        {
            return $this->get_main_menu_items($media_url, $plugin_cookies);
        }

        if (intval($from_ndx) > 0)
            --$from_ndx; // replace aux "loading" item
            
	    $videos = false;
        $folder_items = array();
        $total_num = 0;

        HD::decode_user_data($media_url, $media_str, $user_data);

        if (HD::has_attribute($user_data, 'season_ref'))
        {
            if (HD::has_attribute($user_data, 'season_ref'))
                $season_ref = $user_data->season_ref;
            else if (HD::has_attribute($user_data, 'fav'))
                $season_ref = $user_data->fav;
            $videos = $this->parse_season($season_ref, $plugin_cookies);
            $total_num = 0;
                
           if ($videos === false)
            {
		        //hd_print("--> get_regular_folder_items(): no more available.");
                $caption = (is_interface_language_russian_or_similar() ? 'Больше ничего не найдено' : 'No more items found');
                $m_url = 'dummy';
                if (HD::has_attribute($user_data, 'fav'))
                {
                    $caption = (is_interface_language_russian_or_similar() ? 'Hе найдено' : 'Not found');
                    $m_url = $media_url;
                }
		        $more_items_available = 0;
                
                if ($media_url === 'main_menu:fav')
                {
                    $folder->set_expired();
                }

                $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
		        array_push
		        (
                    $folder_items,
                    array
			        (
                        PluginRegularFolderItem::media_url => $m_url,
	                    PluginRegularFolderItem::caption => $caption,
                	    PluginRegularFolderItem::view_item_params => array
                        	    (
                                    ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : 50)),
                                    ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : 50)),
                                    ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai'),
                		            ViewItemParams::item_detailed_icon_path => 'missing://'
                        		)
			        )
		        );
                ++$total_num;
                
                $this->fav_build_in_progess = false;
            }
            else
            {
                //hd_print("--> get_regular_folder_items(): items count: " . count($videos));
                $more_items_available = 0;

                foreach ($videos as $v)
                {
                    HD::decode_user_data($v, $media_str, $user_data);

                    array_push
                    (
                        $folder_items, 
                        array
                        (
                            PluginRegularFolderItem::media_url => $v,
                            PluginRegularFolderItem::caption => $user_data->episode_title,
                            PluginRegularFolderItem::view_item_params => array(
                                        ViewItemParams::item_paint_icon => true,
                                        ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                                        ViewItemParams::item_layout => HALIGN_LEFT,
                                        ViewItemParams::icon_valign => VALIGN_CENTER,
                                        ViewItemParams::icon_dx => 20,
                                        ViewItemParams::icon_dy => -5,
                                        ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
                                        ViewItemParams::item_caption_width => 1550
                            ),
                        )
                     );
            
                    ++$total_num;
                }
            }
            return array(
                PluginRegularFolderRange::total => $total_num,
                PluginRegularFolderRange::count => count($folder_items),
                PluginRegularFolderRange::more_items_available => $more_items_available,
                PluginRegularFolderRange::from_ndx => $from_ndx,
                PluginRegularFolderRange::items => $folder_items
            );
        }
                else if (HD::has_attribute($user_data, 'fav'))
        {
            $v = $this->get_next_fav($user_data->fav, $plugin_cookies);
            
            HD::decode_user_data($v[0], $media_str, $user_data);

            $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
            $video_id = '1';
            $n_series = 1;
            $ndx_series = 0;
            $is_has_new = false;
            $title = "";

            if (HD::has_attribute($user_data, 'video_id'))
                $video_id = $user_data->video_id;

            if (HD::has_attribute($user_data, 'is_has_new'))
                $is_has_new = $user_data->is_has_new;
                
            if (HD::has_attribute($user_data, 'season_title'))
                $title = $user_data->season_title;
                
                    if ($view_type == 1)
                    {
                            array_push(
                                $folder_items, 
                                array(
                                    PluginRegularFolderItem::media_url =>
                                        HD::encode_user_data(
                                            array(
                                                'video_id' => $video_id,
                                                'n_series' => $n_series,
                                                'season_title' => $title
                                            )
                                    ),
                                    PluginRegularFolderItem::caption => ($is_has_new ? '[NEW] ' . $title : $title),
                                    PluginRegularFolderItem::view_item_params => array(
                                        ViewItemParams::icon_path => $this->get_preview_url($user_data),
                                        ViewItemParams::item_paint_caption => false,
                                        ViewItemParams::item_caption_wrap_enabled => TRUE,
            //                            ViewItemParams::item_detailed_info => $info
                                    )
                                ));
                    }
                    else if ($view_type == 2)
                    {
                            array_push(
                                $folder_items, 
                                array(
                                    PluginRegularFolderItem::media_url =>
                                        HD::encode_user_data(
                                            array(
                                                'video_id' => $video_id,
                                                'n_series' => $n_series,
                                            )
                                    ),
                                    PluginRegularFolderItem::caption => ($is_has_new ? '[NEW] ' . $title : $title),
                                    PluginRegularFolderItem::view_item_params => array(
                                        ViewItemParams::icon_path => $this->get_preview_url($user_data),
//                                        ViewItemParams::item_detailed_info => $info
                                    )
                                ));
                    }
                    else
                    {
                        array_push(
                            $folder_items, 
                            array(
                                PluginRegularFolderItem::media_url =>
                                    HD::encode_user_data(
                                        array(
                                            'video_id' => $video_id,
                                            'n_series' => $n_series
                                        )
                                ),
                                PluginRegularFolderItem::caption => ($is_has_new ? '[NEW] ' . $title : $title),
                                PluginRegularFolderItem::view_item_params => array(
                                    ViewItemParams::item_detailed_icon_path => $this->get_preview_url($user_data),
  //                                  ViewItemParams::item_detailed_info => $info
                                )
                            ));
                    }

             $more_items_available = 0;
             $total_num = 1;
             
            return array(
                PluginRegularFolderRange::total => $total_num,
                PluginRegularFolderRange::count => count($folder_items),
                PluginRegularFolderRange::more_items_available => $more_items_available,
                PluginRegularFolderRange::from_ndx => $from_ndx,
                PluginRegularFolderRange::items => $folder_items
            );
        }

        $folder = FolderCache::get($media_url);

        if (HD::has_attribute($user_data, 'category_ref'))
        {
            $videos = $folder->get_elements($from_ndx, $plugin_cookies);
            $total_num = 0;
                
            if ($videos === false)
            {
		     //   hd_print("--> get_regular_folder_items(): no more available.");
                $caption = (is_interface_language_russian_or_similar() ? 'Больше ничего не найдено' : 'No more items found');
                $m_url = 'dummy';
                if (HD::has_attribute($user_data, 'fav'))
                {
                    $caption = (is_interface_language_russian_or_similar() ? 'Hе найдено' : 'Not found');
                    $m_url = $media_url;
                }
		        $more_items_available = 0;
                
                if ($media_url === 'main_menu:fav')
                {
                    $folder->set_expired();
                }

                $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
		        array_push
		        (
                    $folder_items,
                    array
			        (
                        PluginRegularFolderItem::media_url => $m_url,
	                    PluginRegularFolderItem::caption => $caption,
                	    PluginRegularFolderItem::view_item_params => array
                        	    (
                                    ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : 50)),
                                    ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : 50)),
                                    ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai'),
                		            ViewItemParams::item_detailed_icon_path => 'missing://'
                        		)
			        )
		        );
                ++$total_num;
                
                $this->fav_build_in_progess = false;
            }
            else
            {
              //  hd_print("--> get_regular_folder_items(): items count: " . count($videos));
                $more_items_available = 1;

                foreach ($videos as $v)
                {
                    HD::decode_user_data($v, $media_str, $user_data);

                    array_push
                    (
                        $folder_items, 
                        array
                        (
                            PluginRegularFolderItem::media_url => $v,
                            PluginRegularFolderItem::caption => $user_data->subcategory_title,
                            PluginRegularFolderItem::view_item_params => self::$catalog_vip
                        )
                     );
            
                    ++$total_num;
                }
            }
            return array(
                PluginRegularFolderRange::total => $total_num,
                PluginRegularFolderRange::count => count($folder_items),
                PluginRegularFolderRange::more_items_available => $more_items_available,
                PluginRegularFolderRange::from_ndx => $from_ndx,
                PluginRegularFolderRange::items => $folder_items
            );
        }
        else if
        (
            HD::has_attribute($user_data, 'subcategory_ref') ||
            HD::has_attribute($user_data, 'ser_feed') ||
            $media_url === 'main_menu:fav'
        )
        {
       	    $videos = $folder->get_elements($from_ndx, $plugin_cookies);
            $total_num = $folder->get_num_elements();
	            
           if ($videos === false)
            {
		    //    hd_print("--> get_regular_folder_items(): no more available.");
                $caption = (is_interface_language_russian_or_similar() ? 'Больше ничего не найдено' : 'No more items found');
                $m_url = 'dummy';
                if (HD::has_attribute($user_data, 'fav'))
                {
                    $caption = (is_interface_language_russian_or_similar() ? 'Hе найдено' : 'Not found');
                    $m_url = $media_url;
                }
		        $more_items_available = 0;
                
                if ($media_url === 'main_menu:fav')
                {
                    $folder->set_expired();
                }

                $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
		        array_push
		        (
                    $folder_items,
                    array
			        (
                        PluginRegularFolderItem::media_url => $m_url,
	                    PluginRegularFolderItem::caption => $caption,
                	    PluginRegularFolderItem::view_item_params => array
                        	    (
                                    ViewItemParams::icon_width => ($view_type == 1 ? 190 : ($view_type == 2 ? 150 : 50)),
                                    ViewItemParams::icon_height => ($view_type == 1 ? 290 : ($view_type == 2 ? 200 : 50)),
                                    ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai'),
                		            ViewItemParams::item_detailed_icon_path => 'missing://'
                        		)
			        )
		        );
                ++$total_num;
                
                $this->fav_build_in_progess = false;
            }
            else
            {
	          //  hd_print("--> get_regular_folder_items(): subcategory_ref: items count: " . count($videos));
                if ($media_url === 'main_menu:fav')
                    $this->fav_build_in_progess = true;
                else
                    $this->fav_build_in_progess = false;

                $more_items_available = 1;

                foreach ($videos as $v)
                {
	                HD::decode_user_data($v, $media_str, $user_data);
		    
		            $genre = ' ';
		            if (HD::has_attribute($user_data, 'genre'))
			            $genre = $user_data->genre;

                    $duration = ' ';
		            if (HD::has_attribute($user_data, 'duration'))
			            $duration = $user_data->duration;

                    if (is_interface_language_russian_or_similar())
                    {
		                $genre_caption = 'Жанр';
                        $duration_caption = 'Продолжительность';
                    }
                    else
                    {
		                $genre_caption = 'Genre';
                        $duration_caption = 'Duration';
                    }

                    $info = '';
                    $title = ' ';
                    // Workaround for a bug in Shell.
                    if (HD::has_attribute($user_data, 'season_title'))
                        $title = str_replace('^', '', $user_data->season_title);
                                
                    $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;

                   
		            $video_id = '1';
		            $n_series = 1;
		            $ndx_series = 0;
                    $is_has_new = false;

		            if (HD::has_attribute($user_data, 'video_id'))
	                    $video_id = $user_data->video_id;

 		            if (HD::has_attribute($user_data, 'n_series'))
	                    $n_series = $user_data->n_series;

                    if (HD::has_attribute($user_data, 'is_has_new'))
                        $is_has_new = $user_data->is_has_new;

                    if ($view_type == 1)
                    {
                            array_push(
                                $folder_items, 
                                array(
                                    PluginRegularFolderItem::media_url =>
                                        HD::encode_user_data(
                                            array(
				                	            'video_id' => $video_id,
                                                'n_series' => $n_series,
                                                'season_title' => $title
				                            )
			                        ),
                                    PluginRegularFolderItem::caption => ($is_has_new ? '[NEW] ' . $title : $title),
                                    PluginRegularFolderItem::view_item_params => array(
                                        ViewItemParams::icon_path => $this->get_preview_url($user_data),
                                        ViewItemParams::item_paint_caption => false,
                                        ViewItemParams::item_caption_wrap_enabled => TRUE,
            //                            ViewItemParams::item_detailed_info => $info
                                    )
                                ));
                    }
                    else if ($view_type == 2)
                    {
                            array_push(
                                $folder_items, 
                                array(
                                    PluginRegularFolderItem::media_url =>
                                        HD::encode_user_data(
                                            array(
                                                'video_id' => $video_id,
                                                'n_series' => $n_series,
                                            )
                                    ),
                                    PluginRegularFolderItem::caption => ($is_has_new ? '[NEW] ' . $title : $title),
                                    PluginRegularFolderItem::view_item_params => array(
                                        ViewItemParams::icon_path => $this->get_preview_url($user_data),
                                        ViewItemParams::item_detailed_info => $info
                                    )
                                ));
                    }
                    else
                    {
                        array_push(
                            $folder_items, 
                            array(
                                PluginRegularFolderItem::media_url =>
                                    HD::encode_user_data(
                                        array(
                                            'video_id' => $video_id,
                                            'n_series' => $n_series
                                        )
                                ),
                                PluginRegularFolderItem::caption => ($is_has_new ? '[NEW] ' . $title : $title),
                                PluginRegularFolderItem::view_item_params => array(
                                    ViewItemParams::item_detailed_icon_path => $this->get_preview_url($user_data),
                                    ViewItemParams::item_detailed_info => $info
                                )
                            ));
                    }
                }

                array_push(
                    $folder_items, 
                    array(
                        PluginRegularFolderItem::media_url => 'dummy',
                        PluginRegularFolderItem::caption =>
                            (is_interface_language_russian_or_similar() ? 'Загрузка...' : 'Loading...'),
                        PluginRegularFolderItem::view_item_params => array(
                            ViewItemParams::icon_width => ($view_type == 1 ? 63 : ($view_type == 2 ? 150 : 50)),
                            ViewItemParams::icon_height => (1 ? 63 : ($view_type == 2 ? 150 : 50)),
                            ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai'),
                            ViewItemParams::item_detailed_icon_path => 'missing://'
                        )
                    ));

                ++$total_num;
            }
        }

        else if (HD::has_attribute($user_data, 'video_id'))
        {
	        $more_items_available = 0;
            $c = VideoCache::get($user_data->video_id);
            HD::decode_user_data($c, $media_str, $user_data);
	        $vod_info = $this->get_vod_info($media_url, &$plugin_cookies);
	    
	        $series = $vod_info[PluginVodInfo::series];

	        $i = 0;
	        foreach($series as $s)
	        {
		        $info = '';
                $isnew = false;
                $video_id = $user_data->video_id;
                if (isset($plugin_cookies->$video_id))
                {
                    $isnew = !ListUtil::is_in_list($plugin_cookies->$video_id, $s[PluginVodSeriesInfo::playback_url]);
                }
				//{ Viewed items
                $is_viewed = false;
                if (!$isnew)
                {
                    $vs = $video_id . ".viewed";
                    if (isset($plugin_cookies->$vs))
                    {
                        $is_viewed = ListUtil::is_in_list($plugin_cookies->$vs, $s[PluginVodSeriesInfo::playback_url]);
                    }
                }
                //} Viewed items

                array_push
                (
                    $folder_items, 
                    array
                    (
                        PluginRegularFolderItem::media_url =>
                            HD::encode_user_data
                            (
                                array
                                (
					                'video_id' => $user_data->video_id,
					                'ndx_series' => $i,
                                    'url_series' => $s[PluginVodSeriesInfo::playback_url]
				                )
  			                ),
                            //{ Viewed items
                            PluginRegularFolderItem::caption => (
                                                                    $isnew ? "[NEW] " . $s[PluginVodSeriesInfo::name]  : ($is_viewed ? "[VIEWED] " . $s[PluginVodSeriesInfo::name] : $s[PluginVodSeriesInfo::name])
                                                                ),
                            //} Viewed items
                            PluginRegularFolderItem::view_item_params => array(
                                    ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                                    ViewItemParams::item_detailed_info => $info
                            )
                    )
		        );
		        ++$i;
	        }

	        $total_num = $i;
        }
    

        return array(
            PluginRegularFolderRange::total => $total_num,
            PluginRegularFolderRange::count => count($folder_items),
            PluginRegularFolderRange::more_items_available => $more_items_available,
            PluginRegularFolderRange::from_ndx => $from_ndx,
            PluginRegularFolderRange::items => $folder_items
        );
    }

    ///////////////////////////////////////////////////////////////////////
    private function get_episode_url($episode_ref)
    {
      
	  if (preg_match("/flv/i",$episode_ref))
        {
			$url = 'http://ts://127.0.0.1:81/cgi-bin/flv.sh?'. $episode_ref;
		}
		else
		{
			$url = $episode_ref;
		}
      return($url);
    }
    
    public function get_vod_info($media_url, &$plugin_cookies)
    {
        //hd_print("--> get_vod_info: started...");
 
        if ($media_url === 'dummy')
            return array();

        HD::decode_user_data($media_url, $media_str, $user_data);
        foreach ($user_data as $key => $value)
           // hd_print("  $key => $value");

        $season_ref = "";
        if (!HD::has_attribute($user_data, 'season_ref'))
        {
            if (!HD::has_attribute($user_data, 'video_id'))
                throw new Exception('No season_ref or video_id');
            
            $season_ref = $user_data->video_id;
        }
        else
        {
            $season_ref = $user_data->season_ref;
        }

	    $ndx_series = 0;
        if (HD::has_attribute($user_data, 'ndx_series'))
		    $ndx_series = $user_data->ndx_series;
            
        $title = '';
        if (HD::has_attribute($user_data, 'season_title'))
            $title = $user_data->season_title;

        $descr = '';
        $icon_path = '';
            
	    $series = array();
	    
        $series_urls = $this->parse_season($season_ref, $plugin_cookies);
        
        $video_quality = isset($plugin_cookies->video_quality) ? $plugin_cookies->video_quality : 1;

        $i = 0;
	    foreach ($series_urls as $s)
	    {
	        HD::decode_user_data($s, $media_str, $user_data);
            if ($i === 0)
            {
                if (HD::has_attribute($user_data, 'season_title'))
                    $title = $user_data->season_title;

                if (HD::has_attribute($user_data, 'description'))
                    $descr = $user_data->description;
                if (HD::has_attribute($user_data, 'poster_url'))
                    $icon_path = $user_data->poster_url;
            }
            
            $url = $user_data->episode_ref . "&season_ref=$season_ref";
		    //hd_print("url-+-+->>>: $url");
		    if (strlen($user_data->episode_ref) > 0)
		    {
			    array_push
			    (
				    $series,
		            array
        		    (
                		PluginVodSeriesInfo::name => $user_data->episode_title,
	                	PluginVodSeriesInfo::playback_url => $url,
		                PluginVodSeriesInfo::playback_url_is_stream_url => false
        		    )
			    );
                ++$i;
		    }
	    }
	
        $buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
        //hd_print('--->>> Buffer time: ' . $buf_time);
        mb_internal_encoding("UTF-8");
        return array
        (
            PluginVodInfo::name => $title,
            PluginVodInfo::description => $descr,
            PluginVodInfo::poster_url => $icon_path,
            PluginVodInfo::initial_series_ndx => $ndx_series,
            PluginVodInfo::buffering_ms => $buf_time,
            PluginVodInfo::series => $series
        );
    }
 /////////////////////////////////////////////////////////////////////////////   
	
	    public function get_vod_stream_url($media_url, &$plugin_cookies)
    {
        //hd_print("get_vod_stream_url: starting");
        
        $tmp = explode('&season_ref=', $media_url);

        $media_url = $tmp[0];
       //hd_print("--->>> media_url = $media_url");
		
        $season_ref = $tmp[1];
		if (preg_match("/\.(?:mp3|wav|og(?:g|a)|flac|midi?|rm|m4a|aac|wma|mka|ape)$/i",$media_url))
				{
					return $this->get_episode_url($media_url);				
				}
		else
		{
			//{ Viewed items
			$s = $season_ref . ".viewed";
			if (isset($plugin_cookies->$s))
			{
				if (!ListUtil::is_in_list($plugin_cookies->$s, $media_url))
				{
					$i = $plugin_cookies->$s;
					$plugin_cookies->$s = ListUtil::add_item($i, $media_url);
				}
			}
			else                       
			{
				$plugin_cookies->$s = $media_url;
			}
			//} Viewed items

			return $this->get_episode_url($media_url);
		}
    }

    ///////////////////////////////////////////////////////////////////////

    private function get_loading_items()
    {
        $view_type = isset($plugin_cookies->view_type) ? $plugin_cookies->view_type : 2;
        $items = array(
            array
            (
                PluginRegularFolderItem::caption =>
                    (is_interface_language_russian_or_similar() ? 'Загрузка...' : 'Loading...'),
                PluginRegularFolderItem::view_item_params => array(
                    ViewItemParams::item_paint_icon => true,
                    ViewItemParams::item_layout => HALIGN_LEFT,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::icon_dx => 10,
                    ViewItemParams::icon_width => ($view_type == 1 ? 63 : ($view_type == 2 ? 150 : 50)),
                    ViewItemParams::icon_height => (1 ? 63 : ($view_type == 2 ? 150 : 50)),
                    ViewItemParams::icon_path => ($view_type != 3 ? 'gui_skin://large_icons/movie.aai' : 'gui_skin://small_icons/movie.aai'),
                    ViewItemParams::item_caption_width => 950,
                    ViewItemParams::item_detailed_icon_path => 'missing://'
                ),
                PluginRegularFolderItem::media_url => 'dummy'
            )
        );

        return array(
            PluginRegularFolderRange::total => count($items),
            PluginRegularFolderRange::count => count($items),
            PluginRegularFolderRange::more_items_available => 1,
            PluginRegularFolderRange::from_ndx => 0,
            PluginRegularFolderRange::items => $items
        );
    }

    ///////////////////////////////////////////////////////////////////////
    private function Fussball_main_video($media_url, &$plugin_cookies)
    {
        set_time_limit(0);
        $api = HOST_API_URL;
        $api = $api . "/?nameforhref=films";
		
		$video_sorting = isset($plugin_cookies->video_sorting) ? $plugin_cookies->video_sorting : 1;
		if ($video_sorting == "0")
			{
			$sort_path ='rait';
			}
		elseif ($video_sorting == "1")
			{
			 $sort_path ='new';
			}
		elseif ($video_sorting == "2")
			{
			$sort_path ='prosmotr';
			}
		
		$video_quality = isset($plugin_cookies->video_quality) ? $plugin_cookies->video_quality : 1;
		//hd_print('video_quality--->' . $video_quality);
        
		if ($video_quality == "0")
			{
			$mood_path ='&sortYear=2013';
			}
		elseif ($video_quality == "1")
			{
			 $mood_path ='';
			}
		elseif ($video_quality == "2")
			{
			$mood_path ='&sortYear=2012';
			}
		elseif ($video_quality == "3")
			{
			$mood_path ='&sortYear=2011';
			}
		elseif ($video_quality == "4")
			{
			$mood_path ='&sortYear=2010';
			}
        //hd_print("mood_path--->>> : $mood_path");
		
		$video_resolution = isset($plugin_cookies->video_resolution) ? $plugin_cookies->video_resolution : 1;
		//hd_print('video_quality--->' . $video_production);
        
		if ($video_resolution == "0")
			{
			$resolution_path ='&quality%5B%5D=HD';
			}
		elseif ($video_resolution == "1")
			{
			 $resolution_path ='';
			}
		elseif ($video_resolution == "2")
			{
			$resolution_path ='&quality%5B%5D=HD&quality%5B%5D=HQ';
			}
		elseif ($video_resolution == "3")
			{
			$resolution_path ='&quality%5B%5D=HD&quality%5B%5D=HQ&quality%5B%5D=SQ';
			}
        //hd_print("resolution_path--->>> : $resolution_path");
		
		$video_language = isset($plugin_cookies->video_language) ? $plugin_cookies->video_language : 1;
		if ($video_language == "0")
			{
			$language_path ='&production=foreign';
			}
		elseif ($video_language == "1")
			{
			 $language_path ='';
			}
		elseif ($video_language == "2")
			{
			$language_path ='&production=our';
			}
		
        //$video_production = isset($plugin_cookies->video_production) ? $plugin_cookies->video_production : 1;
		
		// download main video page
        $doc = HD::http_get_document($api);
    
        // get list of categories
        $tmp = explode('<label for="">Жанр</label>', $doc);
        $main_menu_block = strstr($tmp[1], '</div>', true);
        //hd_print("--->>> main_menu_block: $main_menu_block");
        
        $videos = explode('<a href="#" rel="', $main_menu_block);
        // exclude before first <li
        unset($videos[0]);
        $videos = array_values($videos);

        $items = array();
    
        // push 'Последние поступления' category in to categories list
        array_push
        (
            $items,
            array
            (
                PluginRegularFolderItem::caption => 'Все фильмы',
                PluginRegularFolderItem::view_item_params => self::$catalog_vip,
                PluginRegularFolderItem::media_url =>
                        HD::encode_user_data
                        (
                            array
                            (
                                'subcategory_ref' => "/default/index/?nameforhref=films&type=big_list&sortType=$sort_path". $language_path . $resolution_path . $mood_path,
                            )
                        )
            )
        );

        // iterate through categories
        foreach($videos as $video)
        {
            // get category view reference
            $category_ref = strstr($video, '"', true);
			$category_ref =	"/default/index/?nameforhref=films&type=big_list&sortType=$sort_path&janrs%5B%5D=$category_ref". $language_path . $resolution_path . $mood_path;
            // get category title 
            $tmp = explode('">', $video);
            $category_name = strstr($tmp[1], '<', true);
			//hd_print("--->>> category_ref: $category_ref");
            //hd_print("--->>> category_name: $category_name");
        
            // push category in to categories list
            array_push
            (
                $items,
                array
                (
                    PluginRegularFolderItem::caption => $category_name,
                    PluginRegularFolderItem::view_item_params => self::$catalog_vip,
                    PluginRegularFolderItem::media_url =>
                            HD::encode_user_data
                            (
                                array
                                (
                                    'subcategory_ref' => $category_ref,
                                )
                            )
                )
            );
        }

        // hd_print('After parsing: Categories count: ' . count($items));
        
        return $items;
    }
	 ///////////////////////////////////////////////////////////////////////
	private function Fussball_main_genre($media_url, &$plugin_cookies)
    {
        set_time_limit(0);


 $api = HOST_API_URL;
 

$media_url = 'http://nogomya.ch';







$doc = HD::http_get_document($media_url);

$tmp = explode('<h3>Список трансляций</h3>', $doc);

$blok = strstr($tmp[1],'<h5>Моё меню</h5>', true);


$videos = explode('<a href="', $blok);

        
unset($videos[0]);

         





 $videos = array_values($videos);
        
   foreach($videos as $video)
        {




echo $category_ref = 'http://nogomya.ch'.strstr($video,'"', true);


$tmp = explode('">', $video);
   


if (count($tmp) < 2)
                continue;
          

 $category_name = strstr($tmp[1],'</',true);


           echo $category_name = strip_tags($category_name);




// push category in to categories list
            array_push
            (
                $items,
                array
                (
                    PluginRegularFolderItem::caption => $category_name,
                    PluginRegularFolderItem::view_item_params => self::$catalog_vip,
                    PluginRegularFolderItem::media_url =>
                            HD::encode_user_data
                            (
                                array
                                (
                                    'subcategory_ref' => $category_ref,
                                )
                            )
                )
            );
        }

        // hd_print('After parsing: Categories count: ' . count($items));
        
        return $items;
    }
	 /////////////////////////////////////////////////////////////////////// 
    private function Fussball_main_audio($media_url, &$plugin_cookies)
    {
       

 set_time_limit(0);
      

 $api = HOST_API_URL;
        



$media_url = $api.'login';


$user_login = isset($plugin_cookies->user_login) ? $plugin_cookies->user_login : 1;
	

$user_password = isset($plugin_cookies->user_password) ? $plugin_cookies->user_password : 1;






$post =  "LoginForm[username]=".$user_login."&LoginForm[password]=".$user_password."&LoginForm[rememberMe]=1&yt0=Войти";

$ch = curl_init();
curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
curl_setopt($ch, CURLOPT_URL, $media_url);
curl_setopt($ch, CURLOPT_COOKIEJAR, "c.txt");
curl_setopt($ch, CURLOPT_FAILONERROR, true);
curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);

curl_setopt($ch, CURLOPT_REFERER, $media_url);
//curl_setopt($ch, CURLOPT_AUTOREFERER, true);
curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
curl_setopt($ch, CURLOPT_TIMEOUT, 60);
curl_setopt($ch, CURLOPT_POST, 1);
curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
curl_setopt($ch, CURLOPT_COOKIEFILE,"c.txt");

$doc = curl_exec($ch);

curl_close($ch);

$tmp = explode('<h3>Список трансляций</h3>', $doc);

$blok = strstr($tmp[1],'<h5>Моё меню</h5>', true);


$videos = explode('<a href="', $blok);

        
unset($videos[0]);

         





 $videos = array_values($videos);

$items = array();
    
        // push 'Последние поступления' category in to categories list
        array_push
        (
            $items,
            array
            (
                PluginRegularFolderItem::caption => 'Пока пусто',
                PluginRegularFolderItem::view_item_params => self::$catalog_vip,
                PluginRegularFolderItem::media_url =>
                        HD::encode_user_data
                        (
                            array
                            (
                                'subcategory_ref' => "/default/index/?nameforhref=mult&type=big_list&sortType=$sort_path". $language_path . $resolution_path . $mood_path,
                            )
                        )
            )
        );

        // iterate through categories
       




        
   foreach($videos as $video)
        {




echo $category_ref = $api.strstr($video,'"', true);


$tmp = explode('">', $video);
   


if (count($tmp) < 2)
                continue;
          

 $category_name = strstr($tmp[1],'</',true);


           echo $category_name = strip_tags($category_name);





			


//hd_print("--->>> category_ref: $category_ref");
            //hd_print("--->>> category_name: $category_name");
        
            // push category in to categories list
            


array_push
            (
                $items,
                array
                (
                    PluginRegularFolderItem::caption => $category_name,
                    PluginRegularFolderItem::view_item_params => self::$catalog_vip,
                    PluginRegularFolderItem::media_url =>
                            HD::encode_user_data
                            (
                                array
                                (
                                    'subcategory_ref' => $category_ref,
                                )
                            )
                )
            );
        }

        // hd_print('After parsing: Categories count: ' . count($items));
        
        return $items;
    }
    ///////////////////////////////////////////////////////////////////////

  




  private function get_main_menu_items($media_url, &$plugin_cookies)
    {
      

  HD::decode_user_data($media_url,$url,$user_data);
       

 if (update_interface_language())
            FolderCache::clear();

        $skin = isset($plugin_cookies->skin) ? $plugin_cookies->skin : 'default';
	   

 if ($media_url === 'main_menu')
	    {
		    $items = array
		    (
			    

				

				


array
			    (
				    PluginRegularFolderItem::caption => 'футбольные каналы',
				    PluginRegularFolderItem::view_item_params => array(
				            ViewItemParams::icon_path => self::get_skin_path($plugin_cookies) . 'icons/categories.png',
				            ViewItemParams::item_layout => HALIGN_CENTER,
				            ViewItemParams::icon_valign => VALIGN_CENTER,
					        ViewItemParams::item_paint_caption_within_icon => false,
                            ViewItemParams::item_paint_caption => ($skin == 'juniperus' ? true : false),
				            ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
				    ),
				    PluginRegularFolderItem::media_url => 'main_menu:audio'
                ),
			    

array
			    (
				    PluginRegularFolderItem::caption => 'Избранное',
				    PluginRegularFolderItem::view_item_params => array(
				            ViewItemParams::icon_path => self::get_skin_path($plugin_cookies) . 'icons/favorites.png',
				            ViewItemParams::item_layout => HALIGN_CENTER,
				            ViewItemParams::icon_valign => VALIGN_CENTER,
					        ViewItemParams::item_paint_caption_within_icon => false,
                            ViewItemParams::item_paint_caption => ($skin == 'juniperus' ? true : false),
				            ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
				    ),
				    PluginRegularFolderItem::media_url => 'main_menu:fav'
                ),
				


array
			    (
				    PluginRegularFolderItem::caption => 'Поиск',
				    PluginRegularFolderItem::view_item_params => array(
				            ViewItemParams::icon_path => self::get_skin_path($plugin_cookies) . 'icons/search.png',
				            ViewItemParams::item_layout => HALIGN_CENTER,
				            ViewItemParams::icon_valign => VALIGN_CENTER,
					        ViewItemParams::item_paint_caption_within_icon => false,
                            ViewItemParams::item_paint_caption => ($skin == 'juniperus' ? true : false),
				            ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
				    ),
				    PluginRegularFolderItem::media_url => 'main_menu:search'
                ),
				


array
			    (
				    PluginRegularFolderItem::caption => 'Настройки',
				    PluginRegularFolderItem::view_item_params => array(
				            ViewItemParams::icon_path => self::get_skin_path($plugin_cookies) . 'icons/setup.png',
				            ViewItemParams::item_layout => HALIGN_CENTER,
				            ViewItemParams::icon_valign => VALIGN_CENTER,
					        ViewItemParams::item_paint_caption_within_icon => false,
                            ViewItemParams::item_paint_caption => ($skin == 'juniperus' ? true : false),
				       ViewItemParams::item_caption_font_size => FONT_SIZE_NORMAL,
				    ),
		 PluginRegularFolderItem::media_url => 'setup'
                ),
		    );
	    }
 


       


else if ($media_url === 'main_menu:search')
	    {
		    $items = array();
            array_push
            (
                $items,
                array
                (
                    PluginRegularFolderItem::caption => '[Новый запрос]',
                    PluginRegularFolderItem::view_item_params => self::$catalog_vip,
                    PluginRegularFolderItem::media_url =>
                        HD::encode_user_data
                        (
                            array('ser_feed' => '')
                        )
                )
            );

		    $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
		    foreach (ListUtil::string_to_list($search_items) as $item)
		    {
			    if ($item !== "")
			    {
				    array_push
				    (
					    $items,
					    array
					    (
						    PluginRegularFolderItem::caption => (is_interface_language_russian_or_similar() ? "поиск: $item" : "search: $item"),
						    PluginRegularFolderItem::view_item_params => self::$catalog_vip,
						    PluginRegularFolderItem::media_url =>
							    HD::encode_user_data
							    (
								    array('ser_feed' => urlencode($item))
							    )
                        )
                    );
                }
            }
        }
       

 

else if ($media_url === 'main_menu:fav')
	    {
		    $items = array();
		    $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
		    foreach (ListUtil::string_to_list($fav_items) as $item)
		    {
			    if ($item !== "")
			    {
				    $folderRange = $this->get_regular_folder_items(
							    HD::encode_user_data(array('fav' => $item)),
							    0,
							    $plugin_cookies
					   	    );

				    if (!$folderRange)
					    continue;
				    if ($folderRange[PluginRegularFolderRange::count] < 1)
					    continue;

				    array_push
				    (
					    $items,
					    $folderRange[PluginRegularFolderRange::items][0]
                    );
                }
            }
        }
	    
elseif ($media_url === 'main_menu:videos')
	    {
            $items = $this->Fussball_main_video($media_url, $plugin_cookies);
	    }
		

elseif ($media_url === 'main_menu:genres')
	    {
            $items = $this->Fussball_main_genre($media_url, $plugin_cookies);
	    }
		 

elseif ($media_url === 'main_menu:audio')
	    {
            $items = $this->Fussball_main_audio($media_url, $plugin_cookies);
	    }
	   

 return 	array
	    (
		        PluginRegularFolderRange::total => count($items),
		        PluginRegularFolderRange::count => count($items),
	            PluginRegularFolderRange::more_items_available => false,
		        PluginRegularFolderRange::from_ndx => 0,
		        PluginRegularFolderRange::items => $items
	    );
	}
}

///////////////////////////////////////////////////////////////////////////

DefaultDunePluginFw::$plugin_class_name = 'FussballPlugin';

///////////////////////////////////////////////////////////////////////////
?>
